@@ -70,10 +70,13 @@ export const useGlobalStore = defineStore({
     IsSearchOnline: false,  //是否在线搜索
     IsOpenMcpServer: false,  //是否开启mcp服务
     IsOpenKnowledgeBase: false,  //是否开启知识库
-    McpServerList: [], // MCP服务器列表-已勾选
-    McpServerListCheckedName: [], // MCP服务器列表-已勾选
     DefaultAgentName: "default-agent", // 默认MCP服务器
     IsInstallUOSAiAgent: false, // 是否安装UOSAI Agent
+    LastModel: -1, // 最后使用的模型
+    IsShowNonOfficialModelTip: false, // 是否显示过非官方模型提示
+    IsGotFreeCredits: true,  // 是否领取过免费额度
+    IsEnableAdvancedCssFeatures: false,  // 是否启用高级CSS特性（如backdrop-filter等）
+    IsSimplifiedChinese: true,  // 是否为简体中文
     DocParsingStatusType:{
         Success:0x00,
         FileCountError:0x01,
@@ -146,12 +149,6 @@ export const useGlobalStore = defineStore({
         updateMainContentBackgroundColor(res) {
             console.log("updateMainContentBackgroundColor : ", res)
             document.body.style.setProperty("--main-content-background-color", res);
-        },
-        updateMcpServerList(list) {
-            this.McpServerList = list;
-            // 将McpServerList的name取出来形成一个新数组
-            this.McpServerListCheckedName = this.McpServerList.map(server => server.name)
-            this.IsOpenMcpServer = this.McpServerListCheckedName.length > 0;
         }
     },
-});
+});
\ No newline at end of file
