@@ -2,8 +2,7 @@
 
 namespace uos_ai {
 
-Agent::Agent(QObject *parent)
-    : QObject(parent)
+Agent::Agent()
 {
 }
 
