@@ -1,34 +1,30 @@
 #ifndef AGENT_H
 #define AGENT_H
 
-#include "llm.h"
-
-#include <QObject>
 #include <QString>
 #include <QJsonArray>
 #include <QJsonObject>
-#include <QVector>
+#include <QVariantHash>
 
 namespace uos_ai {
 
 /**
  * 智能体基类，定义智能体的基本属性和接口
  */
-class Agent : public QObject
+class Agent
 {
-    Q_OBJECT
 public:
-    explicit Agent(QObject *parent = nullptr);
+    explicit Agent();
     virtual ~Agent();
 
     /**
      * 处理用户请求
      * @param {QJsonObject} question - 当前请求内容
      * @param {QJsonArray} messages - 聊天消息记录
-     * @param {QSharedPointer<LLM>} llm - 模型服务
      * @param {QVariantHash} params - 扩展参数
+     * @returns {QJsonObject} 智能体工作流输出的消息记录
      */
-    virtual void processRequest(const QJsonObject &question, const QJsonArray &messages, QSharedPointer<LLM> llm, const QVariantHash &params = {}) = 0;
+    virtual QJsonObject processRequest(const QJsonObject &question, const QJsonArray &messages, const QVariantHash &params = {}) = 0;
 
     /**
      * 获取智能体名称
