@@ -1,11 +1,11 @@
 #ifndef DEFAULTAGENT_H
 #define DEFAULTAGENT_H
 
-#include "agentrequesthandler.h"
+#include "mcpchatagent.h"
 
 namespace uos_ai {
 
-class DefaultAgent : public AgentRequestHandler
+class DefaultAgent : public MCPChatAgent
 {
     Q_OBJECT
 public:
@@ -16,18 +16,6 @@ public:
      * @returns {MCPServer} MCPServer对象
      */
     QSharedPointer<MCPServer> mcpServer() const override;
-
-    /**
-     * 获取显示名称
-     * @returns {QString} 显示名称
-     */
-    QString displayName() const;
-    
-    /**
-     * 获取图标
-     * @returns {QString} 图标路径或名称
-     */
-    QString icon() const;
     
     /**
      * 获取系统提示词
@@ -39,7 +27,7 @@ public:
      * 创建智能体实例的工厂方法
      * @returns {QSharedPointer<AgentRequestHandler>} 智能体请求处理器实例
      */
-    static QSharedPointer<AgentRequestHandler> create();
+    static QSharedPointer<LlmAgent> create();
     
 protected:
     /**
@@ -49,10 +37,6 @@ protected:
      * @returns {QJsonArray} 初始化后的消息数组
      */
     QJsonArray initChatMessages(const QJsonObject &question, const QJsonArray &history) const override;
-    
-protected:
-    QString m_displayName;  ///< 显示名称
-    QString m_icon;         ///< 图标路径或标识
 };
 
 }
