@@ -10,7 +10,9 @@ class DefaultMcpServer : public MCPServer
 public:
     explicit DefaultMcpServer(const QString &agentName, QObject *parent = nullptr);
 
-    virtual void scanServers();
+    void scanServers() override;
+
+    bool isBuiltin(const QString &name) const override;
 };
 
 }
