@@ -11,6 +11,7 @@
 #include "private/welcomedialog.h"
 #include "esystemcontext.h"
 #include "gui/upgrade/deepseekinfo.h"
+#include "mcpconfigsyncer.h"
 #include <report/chatwindowpoint.h>
 #include <report/eventlogutil.h>
 
@@ -66,6 +67,7 @@ Application::Application(int &argc, char **argv)
 
 
     connect(ServerWrapper::instance(), &ServerWrapper::sigToLaunchMgmt, this, &Application::onLaunchMgmt);
+    connect(ServerWrapper::instance(), &ServerWrapper::sigToLaunchGetFreeAccountDlg, this, &Application::onLaunchGetFreeAccountDlg);
     connect(ServerWrapper::instance(), &ServerWrapper::sigToLaunchChat, this, &Application::onLaunchChat);
     connect(ServerWrapper::instance(), &ServerWrapper::sigToLaunchAbout, this, &Application::onLaunchAbout);
     connect(ServerWrapper::instance(), &ServerWrapper::sigToLaunchWordWizard, this, &Application::onLaunchWordWizard);
@@ -74,6 +76,8 @@ Application::Application(int &argc, char **argv)
     connect(ServerWrapper::instance(), &ServerWrapper::sigAddKnowledgeBase, this, &Application::onAddKnowledgeBasefile);
     connect(ServerWrapper::instance(), &ServerWrapper::sigToTranslate, this, &Application::onTranslate);
     connect(ServerWrapper::instance(), &ServerWrapper::sigToStartScreenshot, this, &Application::onStartScreenshot);
+    connect(ServerWrapper::instance(), &ServerWrapper::sigToLaunchAiQuickOCR, this, &Application::onLaunchAiQuickOCR);
+    connect(ServerWrapper::instance(), &ServerWrapper::sigToUploadImage, this, &Application::onUploadImage);
     connect(&LocalModelServer::getInstance(), &LocalModelServer::sigToLaunchMgmtNoShow, this, &Application::onLaunchMgmtNoShow);
 }
 
@@ -94,6 +98,8 @@ void Application::initialization()
     setAttribute(Qt::AA_UseHighDpiPixmaps);
     initShortcut();
     handleArgumentsParser(arguments());
+
+    McpConfigSyncer::instance()->fetchConfigFromServerAsync();
 }
 
 void Application::initShortcut()
@@ -292,6 +298,25 @@ void Application::launchAiQuickDialog(int type, QString query, QPoint pos, bool
     aiQuickDlg->show();
 }
 
+void Application::launchAiQuickOCRDialog(int type, QString query, QPoint pos, bool isCustom, const QString &imagePath)
+{
+    if (!WelcomeDialog::isAgreed()) {
+        qCInfo(logMain) << "Showing welcome dialog for input prompt";
+        WelcomeDialog::instance(false)->exec();
+        return;
+    }
+    qCInfo(logMain) << "Launching AI quick dialog with type:" << type << "query size:" << query.size();
+    AiQuickDialog *aiQuickDlg = new AiQuickDialog(m_wordWizard);
+    aiQuickDlg->setQuery(type, query, pos, isCustom, imagePath);
+
+    connect(m_wordWizard, &WordWizard::sigToCloseAiQuick, aiQuickDlg, [ aiQuickDlg ] {
+        if (aiQuickDlg)
+            aiQuickDlg->close();
+    });
+
+    aiQuickDlg->show();
+}
+
 void Application::launchAiWriterDialog()
 {
     qCInfo(logMain) << "Launching AI writer dialog";
@@ -378,6 +403,12 @@ void Application::onLaunchMgmt(bool showAddllmPage, bool onlyUseAgreement, bool
     launchMgmtWindow(showAddllmPage, onlyUseAgreement, isFromAiQuick, locateTitle);
 }
 
+void Application::onLaunchGetFreeAccountDlg()
+{
+    launchMgmtWindow(false);
+    m_mgmtWindow->showGetFreeAccountDlg();
+}
+
 void Application::onLaunchMgmtNoShow()
 {
     launchMgmtWindowNoShow();
@@ -403,6 +434,11 @@ void Application::onLaunchAiQuick(int type, QString query, QPoint pos, bool isCu
     launchAiQuickDialog(type, query, pos, isCustom);
 }
 
+void Application::onLaunchAiQuickOCR(int type, QString query, QPoint pos, bool isCustom, const QString &imagePath)
+{
+    launchAiQuickOCRDialog(type, query, pos, isCustom, imagePath);
+}
+
 void Application::onLaunchAiWriter()
 {
     launchAiWriterDialog();
@@ -545,3 +581,24 @@ void Application::onStartScreenshot()
         m_chatWindow->startScreenshot();
     }
 }
+
+void Application::onUploadImage(const QString &imagePath)
+{
+    if (QThread::currentThread() != qApp->thread()) {
+        qCWarning(logMain) << "Upload image called from non-main thread";
+        return;
+    }
+
+    if (m_chatWindow == nullptr) {
+        qCInfo(logMain) << "Launching chat window for upload image";
+        launchChatWindow(ChatIndex::Text);
+        if (m_chatWindow == nullptr) {
+            qCWarning(logMain) << "Agreement is not accepted";
+            return;
+        }
+    } else {
+        m_chatWindow->onlyShowWindow();
+    }
+
+    m_chatWindow->appendImage(imagePath);
+}
