@@ -41,6 +41,8 @@ public:
 
     void launchAiQuickDialog(int type, QString query, QPoint pos, bool isCustom);
 
+    void launchAiQuickOCRDialog(int type, QString query, QPoint pos, bool isCustom, const QString &imagePath);
+
     void launchAiWriterDialog();
 
     void initWordWizard(UOSAI_NAMESPACE::WordWizard *wizard);
@@ -54,6 +56,8 @@ public slots:
 private slots:
     void onLaunchMgmt(bool, bool onlyUseAgreement = false, bool isFromAiQuick = false, const QString &locateTitle = "");
 
+    void onLaunchGetFreeAccountDlg();
+
     void onLaunchChat(int index);
 
     void onLaunchAbout();
@@ -64,6 +68,8 @@ private slots:
 
     void onLaunchAiQuick(int type, QString query, QPoint pos, bool isCustom);
 
+    void onLaunchAiQuickOCR(int type, QString query, QPoint pos, bool isCustom, const QString &imagePath);
+
     void onLaunchAiWriter();
 
     void onInputPrompt(const QString &question, const QMap<QString, QString> &params);
@@ -76,6 +82,8 @@ private slots:
 
     void onStartScreenshot();
 
+    void onUploadImage(const QString &imagePath);
+
 private:
     bool checkAgreement();
 
