@@ -14,6 +14,17 @@
 
 Q_DECLARE_LOGGING_CATEGORY(logAudio)
 
+PlayerThread::PlayerThread(AudioPlayer *player): QThread ()
+    , m_player(player)
+{
+
+}
+
+PlayerThread::~PlayerThread()
+{
+
+}
+
 bool PlayerThread::isPlaying() const
 {
     if (m_stop)
@@ -51,6 +62,14 @@ void PlayerThread::appendAudio(const QString &id, QByteArray data, bool isLast)
     m_dataList.push_back(data);
 }
 
+void PlayerThread::stop()
+{
+    m_id.clear();
+    m_isLast = false;
+    m_stop = true;
+    m_dataList.clear();
+}
+
 void PlayerThread::run()
 {
     while (!m_stop) {
@@ -410,3 +429,43 @@ bool AudioPlayer::playFileSync(const QString &id, QString filePath)
 
     return true;
 }
+
+AudioPlayDevice::AudioPlayDevice(const QByteArray &data, QObject *parent)
+    : QIODevice(parent)
+    , m_data(data)
+{
+}
+
+AudioPlayDevice::~AudioPlayDevice()
+{
+
+}
+
+void AudioPlayDevice::setData(QByteArray data)
+{
+    m_data = data;
+    m_written = 0;
+}
+
+void AudioPlayDevice::close()
+{
+    m_written = 0;
+    QIODevice::close();
+}
+
+qint64 AudioPlayDevice::readData(char *data, qint64 maxSize)
+{
+    if (m_written >= m_data.size())
+        return 0;
+    qint64 len = (m_written + maxSize) > m_data.size() ? (m_data.size() - m_written) : maxSize;
+    memcpy(data, m_data.data() + m_written, len);
+    m_written += len;
+    return len;
+}
+
+qint64 AudioPlayDevice::writeData(const char *data, qint64 maxSize)
+{
+    Q_UNUSED(data);
+    Q_UNUSED(maxSize);
+    return -1;
+}
