@@ -107,6 +107,11 @@ void AudioAiassistant::stopTTSDirectly()
 // 朗读
 void AudioAiassistant::textToSpeech()
 {
+    if(!EAiExec()->isAudioOutputAvailable()) {
+        qCWarning(logAudioWizard) << "Audio output device not available";
+        return;
+    }
+
     if (!AudioAiassistantSetting::instance()->getTTSEnable()) {
         qCWarning(logAudioWizard) << "TTS disabled in settings";
         return;
@@ -180,4 +185,4 @@ void AudioAiassistant::stopAsr()
     if (d->m_asr) {
         d->m_asr->stopAsr();
     }
-}
\ No newline at end of file
+}
