@@ -157,13 +157,7 @@ int DbWrapper::initialization(const QString &dir)
         updateAICopilot(false);
         updateThirdPartyMcpAgreement(false);  // 默认不同意使用第三方MCP协议
         //0:侧边栏模式 1：窗口模式
-        updateDisplayMode(
-#ifdef ENABLE_AI_BAR
-                    1
-#else
-                    0
-#endif
-                    );
+        updateDisplayMode(1);
     }
 
     return 0;
@@ -886,7 +880,7 @@ bool DbWrapper::updateUpdatePromptBits(int startBit, int length, int value)
     auto guide = ConfigTable::get(ConfigTable::CopilotUpdatePrompt);
     QString currentValue = guide.value();
     
-    bool ok;
+    bool ok = false;
     int binaryData = currentValue.isEmpty() ? 0 : currentValue.toInt(&ok, 2);
     if (!ok) {
         binaryData = 0;
