@@ -22,7 +22,9 @@ enum UpdatePromptBitType {
     SHORTCUT_UPDATE = (0 << 8) | 2,    // 快捷键更新弹窗控制位（第0位开始，2位长度）
     AGENT_UPDATE = (2 << 8) | 1,       // 智能体更新弹窗控制位（第2位开始，1位长度）
     MCP_UPDATE = (3 << 8) | 1,         // MCP更新弹窗控制位（第3位开始，1位长度）
-    PRIVACY_UPDATE = (4 << 8) | 1      // 隐私对话更新弹窗控制位（第4位开始，1位长度）
+    PRIVACY_UPDATE = (4 << 8) | 1,      // 隐私对话更新弹窗控制位（第4位开始，1位长度）
+    AUTO_MCP = (5 << 8) | 1,      // MCP升级为自动模式（第5位开始，1位长度）
+    FREE_CREDITS = (6 << 8) | 1,      // 免费额度（第6位开始，1位长度）
 };
 
 // 辅助函数来提取位配置
