@@ -51,7 +51,8 @@ int BrowsweNativeDbusObject::isFreeAccountValid(const QString &llmId)
 
     int available;
     QString modelUrl;
-    if (QNetworkReply::NoError != UosFreeAccounts::instance().getDeterAccountLegal(aacount.account.apiKey, available, modelUrl)) {
+    bool claimAgain;
+    if (QNetworkReply::NoError != UosFreeAccounts::instance().getDeterAccountLegal(aacount.account.apiKey, available, modelUrl, claimAgain)) {
         qCWarning(logDBus) << "Failed to determine account legality";
         return 9999;
     }
