@@ -5,6 +5,8 @@
 #include "chatdbusinterface.h"
 #include "serverwrapper.h"
 
+#include <report/knowledgefunctionpoint.h>
+#include <report/eventlogutil.h>
 #include <QLoggingCategory>
 #include <QTimer>
 #include <QDBusMetaType>
@@ -38,6 +40,7 @@ void ChatDBusInterface::inputPrompt(const QString &question, const QMap<QString,
 
 void ChatDBusInterface::sendToKnowledgeBase(const QStringList &file)
 {
+    ReportIns()->writeEvent(report::KnowledgeFunctionPoint("File Manager").assemblingData());
     if (file.isEmpty()) {
         qCDebug(logDBus) << "Empty file list, skipping knowledge base update";
         return;
