@@ -2,7 +2,7 @@
 #include "private/esinglewebview.h"
 #include "private/eaiexecutor.h"
 #include "private/echatwndmanager.h"
-#include "private/echeckagreementdialog.h"
+#include "../common/echeckagreementdialog.h"
 #include "dbwrapper.h"
 #include "private/echatbutton.h"
 #include "serverwrapper.h"
@@ -11,6 +11,7 @@
 #include "oscallcontext.h"
 #include "ddedockobject.h"
 #include "tables/configtable.h"
+#include "util.h"
 #ifdef COMPILE_ON_V25
 #include "dlayershellwindow.h"
 #include <ddeshellwayland.h>
@@ -18,6 +19,7 @@
 #include "esystemcontext.h"
 #include "gui/upgrade/shortcutupdatedialog.h"
 #include "gui/upgrade/updatelogdialog.h"
+#include "dbus/shortcutmanager.h"
 #include <wordwizard.h>
 #include <report/chatwindowpoint.h>
 #include <report/eventlogutil.h>
@@ -106,6 +108,9 @@ ChatWindow::ChatWindow(QWidget *parent)
     if (DbWrapper::localDbWrapper().getDisplayMode() == 1) {
         m_displayMode = WINDOW_MODE;
         m_webView->setWindowMode(true);
+    }else {
+        m_displayMode = SIDEBAR_MODE;
+        m_webView->setWindowMode(false);
     }
     QStringList sizeList = DbWrapper::localDbWrapper().getWindowSize().split("#");
     if (sizeList.size() == 2) {
@@ -166,6 +171,8 @@ ChatWindow::ChatWindow(QWidget *parent)
     QDBusConnection session = QDBusConnection::sessionBus();
     session.connect(osCallDbusAppearanceService, osCallDbusAppearancePath, "org.freedesktop.DBus.Properties", "PropertiesChanged",
                     this, SLOT(appearancePropertiesChanged(QString, QVariantMap, QStringList)));
+
+    searchShortCut();
 }
 
 void ChatWindow::appearancePropertiesChanged(QString interface, QVariantMap changedProperties, QStringList)
@@ -276,6 +283,29 @@ void ChatWindow::showSidebarMode()
     DbWrapper::localDbWrapper().updateDisplayMode(SIDEBAR_MODE);
 }
 
+void ChatWindow::searchShortCut()
+{
+    qCInfo(logAIGUI) << "Search application shortcuts";
+    ShortcutManager& shortcutMgr = ShortcutManager::getInstance();
+
+    if (!shortcutMgr.isValid()) {
+        qCWarning(logAIGUI) << "ShortcutManager D-Bus interface is not valid";
+        return;
+    }
+
+    // 查询现有快捷键
+    QList<ShortcutInfo> shortcuts = shortcutMgr.searchShortcuts("UOS AI");
+    ShortcutInfo uosAiShortcut;
+
+    for (const ShortcutInfo &shortcut : shortcuts) {
+        if (shortcut.id == "UOS AI") {
+            uosAiShortcut = shortcut;
+        }
+    }
+
+    m_currentShortcut = uosAiShortcut.accel;
+}
+
 void ChatWindow::setW(int w)
 {
     setFixedWidth(w);
@@ -333,8 +363,12 @@ void ChatWindow::activeShowWindow()
 
 QString ChatWindow::getLatestUpdateLogVersion()
 {
-    QString locale = QLocale::system().name(); // 获取系统语言环境，如 "zh_CN" 或 "en_US"
-    QString filePath = QString(":/assets/updatelog/updatelog-%1.json").arg(locale);
+    QString filePath {};
+    if (Util::checkLanguage()) {
+        filePath = ":/assets/updatelog/updatelog-zh_CN.json";
+    } else {
+        filePath = ":/assets/updatelog/updatelog-en_US.json";
+    }
 
     QFile file(filePath);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -461,7 +495,7 @@ void ChatWindow::onMenuTriggered(QAction *action)
         DStyle::setRedPointVisible(m_updateLogAction, false);
         DStyle::setRedPointVisible(titlebar()->findChild<DIconButton *>("DTitlebarDWindowOptionButton"), false);
 
-        uos_ai::UpdateLogDialog dialog(this);
+        uos_ai::UpdateLogDialog dialog;
         dialog.exec();
     }
 }
@@ -608,6 +642,8 @@ void ChatWindow::appendQuestion(const QString &question)
 
 void ChatWindow::appendImage(const QString &imagePath)
 {
+    if (!EAsync()->executeSynchronouslyGeneric(EAsyncWorker::AppendImage))
+        return;
     if (m_isDigitalMode) {
         m_webView->setToChatMode();
         if (m_displayMode == WINDOW_MODE)
@@ -806,7 +842,6 @@ void ChatWindow::startScreenshot()
 
 bool ChatWindow::getThirdPartyMcpAgreement()
 {   
-
     //先查询数据库，没同意就弹窗
     if(DbWrapper::localDbWrapper().getThirdPartyMcpAgreement()){
         qCDebug(logAIGUI) << "The tripartite MCP server agreement is now agreed upon." ;
@@ -936,6 +971,63 @@ bool ChatWindow::showLostFileWarningDlg(const QString lostFileList)
     return false;
 }
 
+bool ChatWindow::showInstallUosAIAgentDlg(QString appName)
+{
+    DDialog dlg(this);
+    dlg.setMinimumWidth(380);
+    dlg.setIcon(QIcon(":/assets/images/warning.svg"));
+    dlg.addButton(tr("Use later"), true, DDialog::ButtonNormal);
+    dlg.addButton(tr("Install Now"), true, DDialog::ButtonRecommend);
+
+    dlg.setTitle(QString(tr("MCP environment missing")));
+    dlg.setMessage(QString(tr("Please go to the App Store to install UOS AI Agent")));
+    if (dlg.exec() == DDialog::Accepted) {
+        EAiExec()->openInstallWidget(appName);
+    }
+    return true;
+}
+
+int ChatWindow::getTitleBarBtnWidth()
+{
+    auto closeBtn = titlebar()->findChild<QAbstractButton *>("DTitlebarDWindowCloseButton");
+    if (closeBtn){
+        return closeBtn->width();
+    }else {
+        return 50;
+    }
+}
+
+bool ChatWindow::showGetFreeCreditsDlg()
+{
+    DDialog dlg(this);
+    dlg.setMinimumWidth(380);
+    dlg.setIcon(QIcon(":/assets/images/warning.svg"));
+    dlg.addButton(tr("Not Now"), true, DDialog::ButtonNormal);
+    dlg.addButton(tr("Claim Credits"), true, DDialog::ButtonRecommend);
+
+    dlg.setTitle(QString(tr("Free Credits Delivered")));
+    dlg.setMessage(QString(tr("You've used up the free generation credits for your trial account. We've given you an extra 200 free credits valid this month. Explore more features and unlock UOS AI's limitless capabilities!")));
+    if (dlg.exec() == DDialog::Accepted) {
+        return true;
+    }
+    return false;
+}
+
+QString ChatWindow::getCurrentShortcut()
+{
+    return m_currentShortcut;
+}
+
+void ChatWindow::showGetFreeCreditsResultDlg(bool isSuccess)
+{
+    DDialog dlg(this);
+    dlg.setMinimumWidth(380);
+    dlg.setIcon(QIcon(isSuccess ? ":/assets/images/ok_info.svg" : ":/assets/images/warning.svg"));
+    dlg.addButton(tr("OK"), true, DDialog::ButtonRecommend);
+    dlg.setTitle(QString(isSuccess ? tr("Successfully Claimed") : tr("Failed to Claim. Please Try Again.")));
+    dlg.exec();
+}
+
 void ChatWindow::onVoiceConversationStatusChanged(int status)
 {
 //    if (m_voiceConversationStatus == status)
@@ -1434,8 +1526,26 @@ void ChatWindow::onlyShowWidget()
 void ChatWindow::showAboutWindow()
 {
     qCInfo(logAIGUI) << "Showing about window";
+
+    auto sidebarAboutDialogPos=[](const QRect &windowRect, const QRect &dialogRect){
+        QPoint newAboutDialogPos;
+        if (dialogRect.width() > windowRect.width()) {
+            newAboutDialogPos.setX(windowRect.x() + windowRect.width() - dialogRect.width());
+            newAboutDialogPos.setY((windowRect.height() - windowRect.y() - dialogRect.height()) / 2);
+        }
+
+        return newAboutDialogPos;
+    };
+
     auto aboutDialog = this->findChild<DAboutDialog *>();
     if (aboutDialog) {
+        if (DisplayMode::WINDOW_MODE == m_displayMode) {
+            aboutDialog->moveToCenter();
+        } else if (DisplayMode::SIDEBAR_MODE == m_displayMode) {
+            QPoint pos = sidebarAboutDialogPos(this->geometry(), aboutDialog->geometry());
+            aboutDialog->move(pos);
+        }
+
         aboutDialog->show();
         aboutDialog->activateWindow();
         return;
@@ -1447,6 +1557,11 @@ void ChatWindow::showAboutWindow()
     aboutDialog->setVersion(QApplication::applicationVersion());
     aboutDialog->setDescription(tr("UOS AI is a desktop smart assistant, your personal assistant! You can communicate with it using text or voice, and it can help answer questions, provide information, and generate images based on your descriptions."));
 
+    if (DisplayMode::SIDEBAR_MODE == m_displayMode) {
+        QPoint pos = sidebarAboutDialogPos(this->geometry(), aboutDialog->geometry());
+        aboutDialog->move(pos);
+    }
+
     // 备案信息
     QLabel *recordTitleLabel = nullptr;
     QLabel *recordNumLabel   = nullptr;
