@@ -25,6 +25,8 @@
 #include <QLocale>
 #include <QTemporaryDir>
 #include <QQueue>
+#include <QtConcurrent>
+#include "uosfreeaccounts.h"
 class EAiPrompt;
 class EAiExecutor : public QObject
 {
@@ -85,9 +87,12 @@ public:
 
     //Config ai account
     void launchLLMConfigWindow(bool showAddllmPage = false, bool onlyUseAgreement = false, bool isFromAiQuick = false, const QString & locateTitle = "");
+    void launchLLMConfigWindowAndGetFreeDialog();
 
     void launchKnowledgeBaseConfigWindow();
 
+    void launchMcpConfigWindow();
+
     void launchAboutWindow();
 
     //Get Ai FAQ
@@ -193,14 +198,15 @@ public:
     void showUpdateDialog(const QString &msg, const QString &appName);
 
     void showPromptWindow();
+    void changeFreeAccountGuide(bool isShowFreeAccountGuide, bool isPreShow = false);
 
     void updateUpdatePromptDB(bool isClicked);
+    void updateUpdateFreeAccountGuideDB(bool isClicked);
 
     // Agent
-    QString getMcpServers(const QString &agentName);
-    QString addCustomMcpServer(const QString &agentName, const QString &jsonConf);
-    QString removeCustomMcpServer(const QString &agentName, const QString &mcpServerName);
+    QStringList getMcpServers(const QString &agentName);
     bool getThirdPartyMcpAgreement();
+    bool isInstallUosAiAgent(const QString &agentName);// mcp环境检查
 
     // Screenshot
     void startScreenshot();
@@ -213,6 +219,21 @@ public:
 
     bool showLostFileWarningDlg(const QString lostFileList);
 
+    // mcp环境缺失弹窗
+    bool showInstallUosAIAgentDlg();
+
+    bool getFreeCredits(bool isShowDlg);  // 领取免费额度
+
+    bool getIsShowFreeAccountGuide() {
+        return m_isShwoFreeAccountGuide;
+    }
+
+    // 查询当前快捷键设置
+    QString getCurrentShortcut();
+
+    // 当前是否为简体中文
+    bool isSimplifiedChinese();
+
 private:
     void startScreenshotInternal();
 
@@ -270,7 +291,9 @@ signals:
 
     void sigHideHistoryList();
 
-    void sigToShowPromptWindow();
+    void sigToShowPromptWindow(int titleBarBtnWidth);
+
+    void sigToChangeFreeAccountGuide(bool isShowFreeAccountGuide, bool isPreShow);
 
     void sigInputFocus();
 
@@ -279,6 +302,9 @@ signals:
     void sigShowTip(const QString &msg);
 
     void sigWordWizardAsk(const QString &askQuestion);
+
+    void sigClaimUsageResult(bool ret, const QString &msg);
+    void sigClaimAgain(bool claimAgain);
 public slots:
     void onPPTCreated(const QString &id, const QList<QByteArray> &imageData);
     void onPPTChanged(const QString &id, const QList<QByteArray> &imageData);
@@ -298,6 +324,8 @@ protected slots:
     void onScreenshotCustomDone(const QString &imagePath);
     void onScreenshotCallFinished(QDBusPendingCallWatcher *watcher);
 
+    void onAccountUsageClaimed(bool ret, const QString &msg);
+
 protected:
     //Private methods
     void loadAiFAQ();
@@ -317,9 +345,6 @@ protected:
     using AiCallQueue = QMap<QString, QSharedPointer<EAiCallback>>;
     AiCallQueue m_callQueue;
 
-    //Ai temperature
-    qreal m_temperature {1.0};
-
     const int   m_limitAQCount {6};
     EAiFAQInit m_faqInitTool;
     QVector<QJsonObject> m_aiFAQ;
@@ -380,6 +405,10 @@ protected:
     ConversionMode m_conversionMode = ConversionMode::Normal;
 
     int m_inputFileSize = 0;
+
+    UosFreeAccountActivity m_hasActivity;
+    UosFreeModelActivity m_hasModelActivity;
+    bool m_isShwoFreeAccountGuide = false;  // 是否显示免费额度领取引导界面
 private:
     //Make ai request context
     QString makeAiReqContext(QSharedPointer<EAiPrompt> prompt, bool isFAQGeneration = false);
@@ -420,6 +449,7 @@ private:
 
     void writeAssistantChatTypeEvent(ConversionType type);
 
+    void JudgeIsShowFreeAccountGuide();
 };
 
 #define EAiExec() (ESingleton<EAiExecutor>::getInstance())
