@@ -18,6 +18,7 @@
 #include <QDBusReply>
 #include <QFileInfo>
 #include <report/screenshotclickedpoint.h>
+#include <report/mcpchatpoint.h>
 #include <report/eventlogutil.h>
 
 Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
@@ -137,6 +138,7 @@ EAiProxy::EAiProxy(QObject *parent)
     connect(EAiExec(), &EAiExecutor::sigHideHistoryList, this, &EAiProxy::sigHideHistoryList);
 
     connect(EAiExec(), &EAiExecutor::sigToShowPromptWindow, this, &EAiProxy::sigToShowPromptWindow);
+    connect(EAiExec(), &EAiExecutor::sigToChangeFreeAccountGuide, this, &EAiProxy::sigToChangeFreeAccountGuide);
 
     connect(EAiExec(), &EAiExecutor::sigMainContentBackgroundColor, this, [this](QString color){
         m_backgroundColor = color;
@@ -150,6 +152,9 @@ EAiProxy::EAiProxy(QObject *parent)
 
     connect(EAiExec(), &EAiExecutor::sigWordWizardAsk, this, &EAiProxy::sigWordWizardAsk);
 
+    connect(EAiExec(), &EAiExecutor::sigClaimUsageResult, this, &EAiProxy::sigGetFreeCreditsResult);
+    connect(EAiExec(), &EAiExecutor::sigClaimAgain, this, &EAiProxy::sigIsGotFreeCredits);
+
     initAsyncWorkerConn();
 }
 
@@ -347,6 +352,11 @@ void EAiProxy::updateUpdatePromptDB(bool isClicked)
     EAiExec()->updateUpdatePromptDB(isClicked);
 }
 
+void EAiProxy::updateUpdateFreeAccountGuideDB(bool isClicked)
+{
+    EAiExec()->updateUpdateFreeAccountGuideDB(isClicked);
+}
+
 void EAiProxy::writeVueLog(int level, const QString &msg)
 {
     switch (level)
@@ -368,21 +378,6 @@ void EAiProxy::writeVueLog(int level, const QString &msg)
     }
 }
 
-QString EAiProxy::getMcpServers(const QString &agentName)
-{
-    return EAiExec()->getMcpServers(agentName);
-}
-
-QString EAiProxy::addCustomMcpServer(const QString &agentName, const QString &jsonConf)
-{
-    return EAiExec()->addCustomMcpServer(agentName, jsonConf);
-}
-
-QString EAiProxy::removeCustomMcpServer(const QString &agentName, const QString &mcpServerName)
-{
-    return EAiExec()->removeCustomMcpServer(agentName, mcpServerName);
-}
-
 void EAiProxy::installUosAiAgent()
 {
     return EAiExec()->openInstallWidget(UOSAIAGENTNAME);
@@ -402,6 +397,11 @@ bool EAiProxy::getThirdPartyMcpAgreement()
     return  EAiExec()->getThirdPartyMcpAgreement();
 }
 
+bool EAiProxy::isInstallUosAiAgent(const QString &agentName)
+{
+    return  EAiExec()->isInstallUosAiAgent(agentName);
+}
+
 void EAiProxy::setInputFileSize(int inputFileSize)
 {
     return EAiExec()->setInputFileSize(inputFileSize);
@@ -517,6 +517,26 @@ bool EAiProxy::showLostFileWarningDlg(const QString lostFileList)
     return EAiExec()->showLostFileWarningDlg(lostFileList);
 }
 
+bool EAiProxy::showInstallUosAIAgentDlg()
+{
+    return EAiExec()->showInstallUosAIAgentDlg();
+}
+
+void EAiProxy::mcpDataUpload(const QString &mcpToUse)
+{
+    QString mcpName;
+    int dotCount = mcpToUse.count('.');
+    if (dotCount == 1) {
+        // Split the string by dot and take the first part as mcpName
+        mcpName = mcpToUse.split('.').first();
+    } else {
+        // If no dot or multiple dots exist, use the original string
+        mcpName = mcpToUse;
+    }
+    // tid:1001600014 event:mcp_chat
+    ReportIns()->writeEvent(report::MCPChatPoint(mcpName).assemblingData());
+}
+
 QString EAiProxy::getNotifierName(AiAction act, int mode)
 {
     Q_UNUSED(act);
@@ -659,11 +679,45 @@ void EAiProxy::launchLLMConfigWindow(bool showAddllmPage)
     return EAiExec()->launchLLMConfigWindow(showAddllmPage, false, false, locateTitle);
 }
 
+void EAiProxy::launchLLMConfigWindowAndGetFreeDialog()
+{
+    return EAiExec()->launchLLMConfigWindowAndGetFreeDialog();
+}
+
+bool EAiProxy::getFreeCredits(bool isShowDlg)
+{
+    return EAiExec()->getFreeCredits(isShowDlg);
+}
+
+QString EAiProxy::getCurrentShortcut()
+{
+    return EAiExec()->getCurrentShortcut();
+}
+
+bool EAiProxy::isEnableAdvancedCssFeatures()
+{
+    #ifdef COMPILE_ON_QT6
+        return true;
+    #else
+        return false;
+    #endif
+}
+
+bool EAiProxy::isSimplifiedChinese()
+{
+    return EAiExec()->isSimplifiedChinese();
+}
+
 void EAiProxy::launchKnowledgeBaseConfigWindow()
 {
     return EAiExec()->launchKnowledgeBaseConfigWindow();
 }
 
+void EAiProxy::launchMcpConfigWindow()
+{
+    return EAiExec()->launchMcpConfigWindow();
+}
+
 void EAiProxy::launchAboutWindow()
 {
     return EAiExec()->launchAboutWindow();
@@ -1081,5 +1135,25 @@ QJsonObject EAiProxy::loadTranslations()
     translations["Recommend official models"] = tr("Recommend official models");
     translations["Disable MCP"] = tr("Disable MCP");
 
+    // 2.12需求
+    translations["It is recommended to use the official model \"DeepSeek-Trial Account\""] = tr("It is recommended to use the official model \"DeepSeek-Trial Account\"");  // 推荐使用官方模型"DeepSeek-试用账号"
+    translations["Quick Open"] = tr("Quick Open");  // 快速唤起
+    translations["MCP Server Upgrade to Automatic Mode"] = tr("MCP Server Upgrade to Automatic Mode");  // MCP服务升级自动模式
+    translations["MCP Server have been upgraded to automatic mode, allowing you to access all MCP Server with just click "] = tr("MCP Server have been upgraded to automatic mode, allowing you to access all MCP Server with just click ");  //MCP服务升级自动模式，仅需打开  
+    translations[". This allows you to automate tasks like system setup and file processing with just one click."] = tr(". This allows you to automate tasks like system setup and file processing with just one click.");   //按钮即可使用所有MCP服务。您可以一句话完成系统设置、文件处理等自动化任务。
+    translations["Adding MCP Server has been moved to Settings."] = tr("Adding MCP Server has been moved to Settings.");  // 添加MCP服务移至设置
+    translations["To add more MCP Server, go to Settings > MCP Server."] = tr("To add more MCP Server, go to Settings > MCP Server.");  // 如需添加更多MCP服务，请到"设置-MCP服务"中添加。
+    translations["Got it"] = tr("Got it");  // 知道了
+    translations["Complimentary Model Credits"] = tr("Complimentary Model Credits");  //  【福利】模型额度赠送
+    translations["The current system offers the DeepSeek trial account model, which automatically refreshes the free quota at the beginning of each month, allowing you to use it worry-free."] = tr("The current system offers the DeepSeek trial account model, which automatically refreshes the free quota at the beginning of each month, allowing you to use it worry-free.");  // 当前系统免费模型DeepSeek-试用账号，将为你在每月1日自动赠送200次文本对话额度，当月有效。
+    translations["Claim Credits"] = tr("Claim Credits");  // 领取额度
+    translations["Get a free account"] = tr("Get a free account");  // 领取免费账号
+    translations["Claim Free Credits"] = tr("Claim Free Credits");  // 领取免费额度
+    translations["Successfully Claimed"] = tr("Successfully Claimed");  // 领取成功
+    translations["Failed to Claim. Please Try Again."] = tr("Failed to Claim. Please Try Again.");  // 领取失败，请再试一次
+    translations["Enable MCP Server&"] = tr("Enable MCP Server&");  // 开启MCP服务
+    translations["Disable MCP Server"] = tr("Disable MCP Server");  // 关闭MCP服务
+    translations["Configure MCP Server"] = tr("Configure MCP Server");  // 配置MCP服务
+
     return translations;
-}
+}
\ No newline at end of file
