@@ -121,13 +121,18 @@ signals:
 
     void sigHideHistoryList();
 
-    void sigToShowPromptWindow();
+    void sigToShowPromptWindow(int titleBarBtnWidth);
+
+    void sigToChangeFreeAccountGuide(bool isShowFreeAccountGuide, bool isPreShow);
 
     void sigInputFocus();
 
     void sigShowTip(const QString &msg);
 
     void sigWordWizardAsk(const QString &askQuestion);
+
+    void sigIsGotFreeCredits(bool isGotFreeCredits);
+    void sigGetFreeCreditsResult(bool success, const QString &msg);  // 免费额度获取结果
 public slots:
     //Js Call this method to notify C++
     //error
@@ -208,10 +213,14 @@ public slots:
      * @param showAddllmPage Show account add dialog if true
      */
     void launchLLMConfigWindow(bool showAddllmPage = false);
+
     /**
      * @brief launchKnowledgeBaseConfigWindow Show ai config window and locate the knowledgeBase
      */
     void launchKnowledgeBaseConfigWindow();
+
+    void launchMcpConfigWindow();
+
     /**
      * @brief showToast
      * @param type AiToast
@@ -429,16 +438,15 @@ public slots:
     bool showWarningDialog(const QString assistantId, const QString conversationId, const QString msg, bool isDelete, bool isLlmDelete, bool isAllConvDelete);
 
     void updateUpdatePromptDB(bool isClicked);
+    void updateUpdateFreeAccountGuideDB(bool isClicked);
     // 0:Debug 1:Info 2:Warning 3:Critical
     void writeVueLog(int level, const QString &msg);
 
     // Agent
-    QString getMcpServers(const QString &agentName);
-    QString addCustomMcpServer(const QString &agentName, const QString &jsonConf);
-    QString removeCustomMcpServer(const QString &agentName, const QString &mcpServerName);
     void installUosAiAgent();
     bool isEnableMcp();
     bool getThirdPartyMcpAgreement();
+    bool isInstallUosAiAgent(const QString &agentName);// mcp环境检查
 
     // Screenshot
     void startScreenshot();
@@ -460,6 +468,23 @@ public slots:
     // 重新编辑用户输入，文件重新走文档解析流程
     void editQuestionToFileSummary(const QStringList fileLists);
     bool showLostFileWarningDlg(const QString lostFileList);
+
+    // mcp环境缺失弹窗
+    bool showInstallUosAIAgentDlg();
+
+    void mcpDataUpload(const QString &mcpToUse);
+
+    void launchLLMConfigWindowAndGetFreeDialog();
+    bool getFreeCredits(bool isShowDlg);  // 领取免费额度
+
+    // 查询当前快捷键设置
+    QString getCurrentShortcut();
+
+    // 是否启用高级CSS特性（如backdrop-filter等）
+    bool isEnableAdvancedCssFeatures();
+
+    // 当前是否为简体中文
+    bool isSimplifiedChinese();
 protected:
     //Property Get methods
 //    int getThemeType() { return m_themeType;}
@@ -483,9 +508,9 @@ protected:
     QString m_fontFamily = "Source Han Sans SC";
     int m_fontPixelSize = 14;
 
-    bool m_isWindowMode = false;
+    bool m_isWindowMode = true;
 
     QString m_backgroundColor;
 };
 
-#endif // EAIPROXY_H
+#endif // EAIPROXY_H
\ No newline at end of file
