@@ -7,6 +7,7 @@
 #include <QFuture>
 #include <QFutureWatcher>
 #include <QtConcurrent>
+#include <QApplication>
 #include <QLoggingCategory>
 
 #include <docparser.h>
@@ -280,7 +281,8 @@ QString EParserDocument::getFileIconData(const QString &docPath)
 
     DFileIconProvider docIcon;
     QIcon idcon = docIcon.icon(docInfo);
-    QImage image = idcon.pixmap(16, 16).toImage();
+    int size = static_cast<int>(qApp->devicePixelRatio() * 16);
+    QImage image = idcon.pixmap(size, size).toImage();
     QByteArray data;
     QBuffer buffer(&data);
     buffer.open(QIODevice::WriteOnly);
