@@ -403,7 +403,6 @@ DWidget *MgmtWindow::initProxyWidget()
     OperatingLineWidget *oper = new OperatingLineWidget(this);
     oper->setName(tr("Proxy Settings"));
     oper->setEditText(tr("Go to settings"));
-    oper->setEditHighlight(true);
 
     connect(oper, &OperatingLineWidget::signalNotDeleteButtonClicked, this, []() {
         DbusControlCenterRequest dbus;
@@ -544,6 +543,11 @@ void MgmtWindow::checkUpdateStatus()
         m_pLocalModelListWidget->updateLocalModelList();
 }
 
+void MgmtWindow::showGetFreeAccountDlg()
+{
+    onShowGetFreeAccountDialog();
+}
+
 void MgmtWindow::onShowGetFreeAccountDialog()
 {
     qCDebug(logAIGUI) << "Showing get free account dialog";
