@@ -9,6 +9,7 @@
 #include "gui/gutils.h"
 #include "private/echatwndmanager.h"
 #include "utils/util.h"
+#include "utils/esystemcontext.h"
 
 #include <DPaletteHelper>
 #include <DMessageManager>
@@ -21,10 +22,13 @@
 #include <QJsonDocument>
 #include <QJsonArray>
 #include <QJsonObject>
+#include <QLoggingCategory>
 
 UOSAI_USE_NAMESPACE
 DCORE_USE_NAMESPACE
 
+Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
+
 AddModelDialog::AddModelDialog(DWidget *parent)
     : DAbstractDialog(parent)
 {
@@ -34,6 +38,10 @@ AddModelDialog::AddModelDialog(DWidget *parent)
     initConnect();
 
     setModal(true);
+    if (ESystemContext::isWayland()) {
+        //wayland环境模态dialog需要手动置顶
+        setWindowFlags(windowFlags() | Qt::Dialog |  Qt::WindowStaysOnTopHint);
+    }
 }
 
 void AddModelDialog::initUI()
@@ -381,8 +389,10 @@ void AddModelDialog::onAddressAlertChanged(bool alert)
 
 void AddModelDialog::onSubmitButtonClicked()
 {
+    qCInfo(logAIGUI) << "Submit button clicked";
     auto llmList = DbWrapper::localDbWrapper().queryLlmList(true);
     if (isNameDuplicate(llmList)) {
+        qCWarning(logAIGUI) << "Duplicate model name detected:" << m_pNameLineEdit->text();
         return;
     }
 
@@ -445,6 +455,7 @@ void AddModelDialog::onSubmitButtonClicked()
     }
 
     if (exist) {
+        qCWarning(logAIGUI) << "LLM already exists, aborting add. Model:" << model << ", Name:" << m_pNameLineEdit->text();
         CommonFailDialog dlg(this);
         dlg.setFailMsg(tr("This LLM already exists, please do not add it again."));
         dlg.exec();
@@ -453,6 +464,7 @@ void AddModelDialog::onSubmitButtonClicked()
 
     //验证KOL账号
     if (isKol) {
+        qCInfo(logAIGUI) << "Verifying KOL account for model:" << model;
         UosFreeAccount freeAccount;
         freeAccount.appid = appId;
         freeAccount.appkey = apiKey;
@@ -465,6 +477,7 @@ void AddModelDialog::onSubmitButtonClicked()
         setAllWidgetEnabled(true);
 
         if (QNetworkReply::NoError == error) {
+            qCInfo(logAIGUI) << "KOL account verified successfully.";
             LLMChatModel m = static_cast<LLMChatModel>(freeAccount.llmModel);
             bool typeError = false; //模型错误，百度两种模型账号可以混用，但是百度和讯飞不能混用
             // 选择正确的时候
@@ -475,6 +488,7 @@ void AddModelDialog::onSubmitButtonClicked()
                     model = DeepSeek_Uos_Free;
                 } else {
                     typeError = true;
+                    qCWarning(logAIGUI) << "KOL account type mismatch. Expected:" << model << ", Got:" << m;
                 }
             }
 
@@ -497,18 +511,20 @@ void AddModelDialog::onSubmitButtonClicked()
                 m_data = llm;
 
                 if (!DbWrapper::localDbWrapper().appendLlm(llm)) {
+                    qCCritical(logAIGUI) << "Failed to save KOL LLM to database.";
                     CommonFailDialog dlg(this);
                     dlg.setFailMsg(tr("Save failed, please try again later"));
                     dlg.exec();
                     return;
                 }
 
+                qCInfo(logAIGUI) << "KOL LLM added successfully.";
                 ServerWrapper::instance()->updateLLMAccount();
                 this->accept();
                 return;
             }
         } else if (1 != status && 3 != status) {
-            //其他错误，但不是1和3，说明是网络或者服务器异常了
+            qCCritical(logAIGUI) << "Network/server error when verifying KOL account. Status:" << status;
             CommonFailDialog dlg(this);
             dlg.setFailMsg(tr("Unable to connect to the server, please check your network or try again later."));
             dlg.exec();
@@ -546,10 +562,12 @@ void AddModelDialog::onSubmitButtonClicked()
     m_data = serverProxy;
 
     setAllWidgetEnabled(false);
+    qCInfo(logAIGUI) << "Verifying LLM server proxy before saving. Model:" << model;
     QPair<int, QString> pair = ServerWrapper::instance()->verify(serverProxy);
     setAllWidgetEnabled(true);
 
     if (0 != pair.first) {
+        qCCritical(logAIGUI) << "LLM server proxy verification failed. Error:" << pair.second;
         CommonFailDialog dlg(this);
         dlg.setFailMsg(pair.second);
         dlg.exec();
@@ -557,12 +575,14 @@ void AddModelDialog::onSubmitButtonClicked()
     }
 
     if (!DbWrapper::localDbWrapper().appendLlm(serverProxy)) {
+        qCCritical(logAIGUI) << "Failed to save LLM to database.";
         CommonFailDialog dlg(this);
         dlg.setFailMsg(tr("Save failed, please try again later"));
         dlg.exec();
         return;
     }
 
+    qCInfo(logAIGUI) << "LLM added successfully.";
     ServerWrapper::instance()->updateLLMAccount();
     this->accept();
 }
@@ -711,6 +731,7 @@ bool AddModelDialog::isNameDuplicate(const QList<LLMServerProxy> &llmList) const
 
 void AddModelDialog::getOpenRouterModelList()
 {
+    qCInfo(logAIGUI) << "Requesting OpenRouter model list.";
     if(m_openrouterModelIDLst.isEmpty() || m_openrouterModelNameLst.isEmpty())
     {
         QNetworkAccessManager manager;
@@ -730,7 +751,7 @@ void AddModelDialog::getOpenRouterModelList()
 
             if (!jsonDoc.isNull()) {
                 if (jsonDoc.isNull()) {
-                    qDebug() << "Failed to parse JSON";
+                    qCCritical(logAIGUI) << "Failed to parse JSON from OpenRouter response.";
                     return;
                 }
 
@@ -741,16 +762,16 @@ void AddModelDialog::getOpenRouterModelList()
                     QJsonObject obj = value.toObject();
                     QString id = obj["id"].toString();
                     QString name = obj["name"].toString();
-                    qDebug() << "ID:" << id << ", Name:" << name;
+                    qCDebug(logAIGUI) << "OpenRouter Model ID:" << id << ", Name:" << name;
 
                     m_openrouterModelIDLst.append(id);
                     m_openrouterModelNameLst.append(name);
                 }
             } else {
-                qDebug() << "Failed to parse JSON response";
+                qCCritical(logAIGUI) << "Failed to parse JSON response from OpenRouter.";
             }
         } else {
-            qDebug() << "Network request failed:" << reply->errorString();
+            qCCritical(logAIGUI) << "Network request to OpenRouter failed:" << reply->errorString();
         }
         reply->deleteLater();
     }
@@ -758,6 +779,7 @@ void AddModelDialog::getOpenRouterModelList()
     for(const QString modelName : m_openrouterModelNameLst) {
         m_modelLstComboBox->addItem(modelName);
     }
+    qCInfo(logAIGUI) << "OpenRouter model list loaded. Count:" << m_openrouterModelNameLst.size();
 }
 
 void AddModelDialog::onCompactModeChanged()
