@@ -14,6 +14,9 @@
 #include <DDialog>
 #include <DArrowRectangle>
 #include <DFloatingWidget>
+#include <report/knowledgefilenumberpoint.h>
+#include <report/knowledgefunctionpoint.h>
+#include <report/eventlogutil.h>
 
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -29,6 +32,8 @@ Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
 
 static const qint64 KnowledgeBaseSize = 1024 * 1024 * 1024;
 
+using namespace uos_ai;
+
 KnowledgeBaseListWidget::KnowledgeBaseListWidget(DWidget *parent)
     : DWidget(parent)
 {
@@ -230,6 +235,7 @@ bool KnowledgeBaseListWidget::onAppendKnowledgeBase(const QString &filePath, int
 
 void KnowledgeBaseListWidget::onAddKnowledgeBase()
 {
+    ReportIns()->writeEvent(report::KnowledgeFunctionPoint("Click Upload").assemblingData());
     DFileDialog fileDlg(this);
     fileDlg.setDirectory(m_lastImportPath);
     QString selfilter = tr("All files") + (" (%1)");
@@ -286,6 +292,7 @@ void KnowledgeBaseListWidget::onIndexDeleted(const QStringList &files)
 
         adjustWidgetSize();
     }
+    ReportIns()->writeEvent(report::KnowledgeFileNumberPoint(KnowledgeBaseManager::getInstance().getKnowledgeBaseFiles().size()).assemblingData());
 }
 
 void KnowledgeBaseListWidget::onFilesProcessing(const QStringList &files)
