@@ -18,33 +18,32 @@ namespace uos_ai {
 class McpServerItem: public DWidget
 {
     Q_OBJECT
-
 public:
     explicit McpServerItem(DWidget *parent = nullptr);
     ~McpServerItem() override;
 
-    void updateStatus();
     void setText(const QString &theme, const QString &summary);
     void setAppName(const QString &appName);
+    void checkUpdateStatus(bool isInstalled);
+    void changeInstallStatus(bool isInstalled);
 
-private slots:
+Q_SIGNALS:
+    void doCheckInstalled();
+
+protected:
+    void resizeEvent(QResizeEvent *event) override;
+
+private Q_SLOTS:
     void onInstall();
     void onUninstall();
     void onUpdate();
-    void checkStatusOntime();
 
 private:
     void initUI();
     void initConnect();
 
-    void checkInstallStatus();
-    void changeInstallStatus();
-    void beginTimer(const int &time);
-    void stopTimer();
-
-    void checkUpdateStatus();
     QString getUpdateVersion(const QByteArray& reply);
-
+    void adjustSummaryLabelWidth();
 private:
     DLabel *m_pNameLabel = nullptr;
     DLabel *m_pDescLabel = nullptr;
@@ -53,14 +52,10 @@ private:
     DSuggestButton *m_pBtnUpdate = nullptr;
 
     QProcess *m_pProcess = nullptr;
-    QTimer *m_timer = nullptr;
 
     QString m_appName = "uos-ai-agent";  // MCP服务的包名
-    bool m_isInstalled = false;
-    int m_timerCount = 0;
-
     QString m_updateVersion;
 };
 }
 
-#endif // MCPSERVERITEM_H
\ No newline at end of file
+#endif // MCPSERVERITEM_H
