@@ -5,12 +5,14 @@
 #include "uosfreeaccounts.h"
 #include "utils/util.h"
 
-#include <QVBoxLayout>
-#include <QHBoxLayout>
-
 #include <DLabel>
 
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QLoggingCategory>
+
 using namespace uos_ai;
+Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
 
 ModelListWidget::ModelListWidget(DWidget *parent)
     : DWidget(parent)
@@ -26,7 +28,7 @@ void ModelListWidget::initUI()
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(10);
 
-    m_pGetFreeAccountButton = new GetFreeAccountButton(tr("Get a free account"), this);//Claim a free account
+    m_pGetFreeAccountButton = new IconCommandLinkButton(tr("Get a free account"), IconPosition::Left, this);//Claim a free account
     m_pGetFreeAccountButton->setIcon(QIcon::fromTheme(":/assets/images/free_account.svg").pixmap(QSize(16, 16)));
     DFontSizeManager::instance()->bind(m_pGetFreeAccountButton, DFontSizeManager::T8, QFont::Normal);
     m_pGetFreeAccountButton->setProperty("editMode", false);
@@ -60,7 +62,7 @@ void ModelListWidget::initUI()
 
 void ModelListWidget::initConnect()
 {
-    connect(m_pGetFreeAccountButton, &DCommandLinkButton::clicked, this, &ModelListWidget::onGetFreeAccount);
+    connect(m_pGetFreeAccountButton, &IconCommandLinkButton::clicked, this, &ModelListWidget::onGetFreeAccount);
     connect(m_pEditButton, &DCommandLinkButton::clicked, this, &ModelListWidget::onEditButtonClicked);
     connect(m_pAddButton, &DCommandLinkButton::clicked, this, &ModelListWidget::signalAddModel);
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &ModelListWidget::onThemeTypeChanged);
@@ -75,6 +77,8 @@ void ModelListWidget::onThemeTypeChanged()
     DPalette pl1 = m_pNoModelWidget->palette();
     pl1.setBrush(DPalette::Base, DGuiApplicationHelper::instance()->applicationPalette().color(DPalette::ItemBackground));
     m_pNoModelWidget->setPalette(pl1);
+
+    qCDebug(logAIGUI) << "Theme type changed for ModelListWidget.";
 }
 
 void ModelListWidget::onEditButtonClicked()
@@ -91,6 +95,7 @@ void ModelListWidget::onEditButtonClicked()
     editMode ? m_pEditButton->setText(tr("Done")) : m_pEditButton->setText(tr("Delete"));
     m_pAddButton->setEnabled(!editMode);
     m_pGetFreeAccountButton->setEnabled(!editMode);
+    qCInfo(logAIGUI) << "Edit button clicked. editMode:" << editMode;
 }
 
 DWidget *ModelListWidget::noModelWidget()
@@ -139,6 +144,7 @@ void ModelListWidget::setModelList(const QList<LLMServerProxy> &llmList)
     }
 
     adjustWidgetSize();
+    qCInfo(logAIGUI) << "Model list set. count:" << llmList.size();
 }
 
 void ModelListWidget::onAppendModel(const LLMServerProxy &llmServerProxy)
@@ -156,7 +162,8 @@ void ModelListWidget::onAppendModel(const LLMServerProxy &llmServerProxy)
 
 void ModelListWidget::onGetFreeAccount()
 {
-  emit signalGetFreeAccountClicked();
+    qCInfo(logAIGUI) << "Get free account button clicked.";
+    emit signalGetFreeAccountClicked();
 }
 
 void ModelListWidget::removeModel(const LLMServerProxy &llmServerProxy)
@@ -169,6 +176,7 @@ void ModelListWidget::removeModel(const LLMServerProxy &llmServerProxy)
     delete item;
 
     adjustWidgetSize();
+    qCInfo(logAIGUI) << "Model removed. id:" << llmServerProxy.id;
 }
 
 void ModelListWidget::adjustWidgetSize()
@@ -195,6 +203,7 @@ void ModelListWidget::resetEditButton()
 {
     if (m_pEditButton->property("editMode").toBool()) {
         onEditButtonClicked();
+        qCDebug(logAIGUI) << "Reset edit button.";
     }
 }
 
