@@ -7,13 +7,9 @@
 #include <DWidget>
 #include <dtkwidget_global.h>
 
-DCORE_BEGIN_NAMESPACE
-class DSettings;
-DCORE_END_NAMESPACE
-
-DWIDGET_BEGIN_NAMESPACE
-
 class NavigationPrivate;
+
+namespace uos_ai {
 class LIBDTKWIDGETSHARED_EXPORT Navigation : public QFrame
 {
     Q_OBJECT
@@ -26,14 +22,13 @@ signals:
 
 public slots:
     void onSelectGroup(const QString &key);
-    void updateNavigationTitles(QList<DWidget *> sortTitles);
+    void updateNavigationTitles(QList<DTK_WIDGET_NAMESPACE::DWidget *> sortTitles);
     void onCurrentChanged(const QModelIndex &current);
 
 private:
     QScopedPointer<NavigationPrivate> d_ptr;
     Q_DECLARE_PRIVATE_D(qGetPtrHelper(d_ptr), Navigation)
 };
-
-DWIDGET_END_NAMESPACE
+}
 
 #endif // NAVIGATION_H
