@@ -21,6 +21,9 @@
 #include <QVBoxLayout>
 #include <QGuiApplication>
 #include <QScreen>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logAIGUI)
 
 using namespace uos_ai;
 
@@ -165,6 +168,7 @@ void DeepSeekInfo::initConnect()
 
 void DeepSeekInfo::onUpdateSystemFont(const QFont &font)
 {
+    qCDebug(logAIGUI) << "Updating system font, new pixel size:" << QFontInfo(font).pixelSize();
     QFont tmpFont = m_pFirstIntroduce->font();
     tmpFont.setPixelSize(QFontInfo(font).pixelSize() + 8);
     m_pFirstIntroduce->setFont(tmpFont);
@@ -173,31 +177,43 @@ void DeepSeekInfo::onUpdateSystemFont(const QFont &font)
 
 void DeepSeekInfo::checkActivity()
 {
+    qCInfo(logAIGUI) << "Starting to check DeepSeek activity status";
     bool dpsk = false;
     for (auto tmp : DbWrapper::localDbWrapper().queryLlmList()) {
         if (tmp.type == FREE_NORMAL) {
             if (tmp.model >= SPARKDESK || tmp.model <= WXQF_ERNIE_Bot_4) {
                 enrie = tmp;
+                qCDebug(logAIGUI) << "Found existing Ernie model:" << tmp.id;
             } else if (tmp.model == DeepSeek_Uos_Free) {
                 dpsk = true;
+                qCDebug(logAIGUI) << "DeepSeek model already exists";
             }
         }
     }
 
-    if (dpsk)
+    if (dpsk) {
+        qCInfo(logAIGUI) << "DeepSeek model already exists, skipping activity check";
         return;
+    }
+    
     adjustReceiveBtn(ReceivedStatus::CHECKING);
 #ifdef ENABLE_FREEACCOUNT
     {
+        qCInfo(logAIGUI) << "Free account enabled, starting activity check";
 #else
         if (UOSAI_NAMESPACE::Util::checkLanguage()) {
+            qCInfo(logAIGUI) << "Language check passed, starting activity check";
 #endif
             QFuture<int> future = QtConcurrent::run([ = ] {
+                qCDebug(logAIGUI) << "Starting background activity check";
                 UosFreeAccountActivity hasActivity;
                 auto error = UosFreeAccounts::instance().freeAccountButtonDisplay("account", hasActivity);
-                if (error != QNetworkReply::NoError)
+                if (error != QNetworkReply::NoError) {
+                    qCWarning(logAIGUI) << "Free account activity check network error:" << error;
                     return (int)error;
+                }
 
+                qCDebug(logAIGUI) << "Activity check result, display flag:" << hasActivity.display;
                 return hasActivity.display != 0 ? 0 : -1;
             });
 
@@ -208,21 +224,25 @@ void DeepSeekInfo::checkActivity()
 
 bool DeepSeekInfo::checkAndShow()
 {
+    qCInfo(logAIGUI) << "Checking if DeepSeek info dialog should be shown";
 
     if (QThread::currentThread() != qApp->thread()) {
         Q_ASSERT_X(QThread::currentThread() == qApp->thread(), __func__, "invalid working thread");
-        qCritical() << " upgrade processing is not called in gui thread.";
+        qCCritical(logAIGUI) << "DeepSeekInfo dialog processing is not called in GUI thread";
         return false;
     }
 
-    if (!needGuide())
+    if (!needGuide()) {
+        qCInfo(logAIGUI) << "Guide not needed, skipping dialog display";
         return true;
+    }
 
     if (isDialogOpen) {
         getInstance().activateWindow();
         return false;
     }
 
+    qCInfo(logAIGUI) << "Showing DeepSeek info dialog";
     isDialogOpen = true;
     getInstance().checkActivity();
     getInstance().adjustSize();
@@ -236,30 +256,37 @@ bool DeepSeekInfo::checkAndShow()
 bool DeepSeekInfo::needGuide()
 {
     auto cur = DbWrapper::localDbWrapper().getGuideKey();
-    if (cur.isEmpty() || cur.toInt() < DbWrapper::builtinGuideVersion())
-        return true;
-
-    return false;
+    bool needsGuide = cur.isEmpty() || cur.toInt() < DbWrapper::builtinGuideVersion();
+    qCInfo(logAIGUI) << "Guide needed check - current:" << cur << "builtin:" << DbWrapper::builtinGuideVersion() << "needs guide:" << needsGuide;
+    return needsGuide;
 }
 
 void DeepSeekInfo::getAccount()
 {
+    qCInfo(logAIGUI) << "Starting to get DeepSeek free account";
     adjustReceiveBtn(ReceivedStatus::RECEIVING);
     {
         QFuture<int> future = QtConcurrent::run([this] {
+            qCDebug(logAIGUI) << "Background thread: Getting free account";
             UosFreeAccount freeAccount;
 
             int status = -1;
             auto error = UosFreeAccounts::instance().getFreeAccount(ModelType::FREE_NORMAL, DeepSeek_Uos_Free, freeAccount, status);
-            if (status == 1) // 活动结束。
+            if (status == 1) { // 活动结束
+                qCWarning(logAIGUI) << "Free account activity has ended";
                 return 1;
-            if (error != QNetworkReply::NoError) // 请求错误，提示稍后再试
+            }
+            if (error != QNetworkReply::NoError) { // 请求错误，提示稍后再试
+                qCWarning(logAIGUI) << "Network error while getting free account:" << error;
                 return -1;
+            }
             if (freeAccount.llmModel != DeepSeek_Uos_Free) {
-                qCritical() << "getFreeAccount error: return model type"  << freeAccount.llmModel
-                            << "need" << DeepSeek_Uos_Free;
+                qCCritical(logAIGUI) << "getFreeAccount error: return model type" << freeAccount.llmModel << "need" << DeepSeek_Uos_Free;
                 return 2;
             }
+            
+            qCInfo(logAIGUI) << "Free account obtained successfully, app key:" << freeAccount.appkey.left(8) + "...";
+            
             LLMServerProxy tmp;
             tmp.id = freeAccount.appkey;
             tmp.type = FREE_NORMAL;
@@ -267,20 +294,25 @@ void DeepSeekInfo::getAccount()
             tmp.account.apiKey = freeAccount.appkey;
             tmp.model = DeepSeek_Uos_Free;
 
-            if (!enrie.id.isEmpty())
+            if (!enrie.id.isEmpty()) {
+                qCInfo(logAIGUI) << "Removing old Ernie model:" << enrie.id;
                 DbWrapper::localDbWrapper().deleteLlm(enrie.id);
+            }
 
+            qCInfo(logAIGUI) << "Adding new DeepSeek model to database";
             DbWrapper::localDbWrapper().appendLlm(tmp);
 
             QList<AssistantProxy> assistantLst = DbWrapper::localDbWrapper().queryAssistantList();
             for (const AssistantProxy &assis : assistantLst) {
                 if (assis.type == AssistantType::UOS_AI) {
+                    qCInfo(logAIGUI) << "Updating UOS AI assistant to use DeepSeek model";
                     DbWrapper::localDbWrapper().updateAssistantLlm(assis.id, tmp.id);
                     break;
                 }
             }
 
             DbWrapper::localDbWrapper().updateGuideKey(QString::number(DbWrapper::builtinGuideVersion()));
+            qCInfo(logAIGUI) << "DeepSeek account setup completed successfully";
             return 0;
         });
 
@@ -293,12 +325,16 @@ void DeepSeekInfo::onCheckActivity()
 {
     disconnect(&watcher, nullptr, this, nullptr);
     int result = watcher.result();
+    qCInfo(logAIGUI) << "Activity check completed with result:" << result;
 
     if (result == 0 ) {
+        qCInfo(logAIGUI) << "Activity exists, showing get account button";
         adjustReceiveBtn(ReceivedStatus::ACTIVITY_EXIST);
     } else if (result == -1) {
+        qCWarning(logAIGUI) << "Activity has ended";
         adjustReceiveBtn(ReceivedStatus::ACTIVITY_OVER);
     } else {
+        qCWarning(logAIGUI) << "Activity check failed";
         adjustReceiveBtn(ReceivedStatus::CHECK_FAIL);
     }
 }
@@ -313,12 +349,16 @@ void DeepSeekInfo::onGetAccount()
 {
     disconnect(&watcher, nullptr, this, nullptr);
     int result = watcher.result();
+    qCInfo(logAIGUI) << "Get account operation completed with result:" << result;
 
     if (result == 0) {
+        qCInfo(logAIGUI) << "Account received successfully";
         adjustReceiveBtn(ReceivedStatus::RECEIVE_SUCCEED);
     } else if (result == 1) {
+        qCWarning(logAIGUI) << "Activity has ended during account retrieval";
         adjustReceiveBtn(ReceivedStatus::ACTIVITY_OVER);
     } else {
+        qCWarning(logAIGUI) << "Failed to receive account";
         adjustReceiveBtn(ReceivedStatus::RECEIVE_FAIL);
     }
 }
