@@ -15,15 +15,16 @@ ChatCompletion360::ChatCompletion360(const AccountProxy &account)
 
 }
 
-QPair<int, QString> ChatCompletion360::create(const QString &model, Conversation360 &conversation, qreal temperature)
+QPair<int, QString> ChatCompletion360::create(const QString &model, Conversation360 &conversation, const QVariantHash &params)
 {
     qCDebug(logLLM) << "360 Creating chat completion with model:" << model
-                   << "and temperature:" << temperature;
+                   << "and temperature:" << params;
 
     QJsonObject dataObject;
     dataObject.insert("model", model);
     dataObject.insert("messages", conversation.getConversions());
-    dataObject.insert("temperature", qBound(0.0, temperature, 1.0));
+    if (params.contains("temperature"))
+         dataObject.insert("temperature", qBound(0.0, params.value("temperature").toDouble(), 1.0));
     dataObject.insert("stream", true);
 
     const QPair<int, QByteArray> &resultPairs = request(dataObject, "/chat/completions");
