@@ -115,3 +115,8 @@ void LLM::textChainContent(const QString &content)
 
     emit readyReadChatDeltaContent(QJsonDocument(wrapper).toJson());
 }
+
+LLMServerProxy LLM::account() const
+{
+    return m_accountProxy;
+}
