@@ -90,6 +90,12 @@ enum ErrorType {
 
     // 知识库异常
     PersonalBaseNotExist = 9100,
+
+    // MCP智能体异常
+    AgentServerUnavailable = 11000,
+    AgentServerInvaildContent = 11001,
+    MCPSeverUnavailable= 11100,
+    MCPToolError = 11101
 };
 
 inline AIServer::ErrorType networkReplyErrorToAiServerError(QNetworkReply::NetworkError type)
