@@ -23,13 +23,11 @@ QJsonObject DeepSeekAI::predict(const QString &content, const QJsonArray &functi
     conversation.addUserData(content);
     conversation.filterThink();
 
-    qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
-
     DeepSeekCompletion chatCompletion(baseUrl(), m_accountProxy.account);
     connect(this, &DeepSeekAI::aborted, &chatCompletion, &DeepSeekCompletion::requestAborted);
     connect(&chatCompletion, &DeepSeekCompletion::readyReadDeltaContent, this, &DeepSeekAI::onReadyReadChatDeltaContent);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversation, temperature);
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversation, m_params);
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
@@ -51,7 +49,21 @@ QPair<int, QString> DeepSeekAI::verify()
     DeepSeekCompletion chatCompletion(baseUrl(), m_accountProxy.account);
     connect(this, &DeepSeekAI::aborted, &chatCompletion, &DeepSeekCompletion::requestAborted);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversation);
+    bool ok = false;
+    connect(&chatCompletion, &DeepSeekCompletion::readyReadDeltaContent, this, [this, &ok](const QByteArray &content) {
+        const QJsonObject &deltacontent = DeepSeekConversation::parseContentString(QString::fromUtf8(content));
+        if (deltacontent.contains("reasoningContent") || deltacontent.contains("content")) {
+            qCInfo(logLLM) << "DeepSeekAI Account verification received content.";
+            ok = true;
+            QMetaObject::invokeMethod(this, "aborted", Qt::QueuedConnection);
+        }
+    });
+
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversation, m_params);
+
+    if (ok)
+        return QPair<int, QString>(0, "");
+
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
