@@ -12,7 +12,7 @@ class DeepSeekCompletion : public BaseNetWork
 public:
     DeepSeekCompletion(const QString &url, const AccountProxy &account);
 
-    QPair<int, QString> create(const QString &model, DeepSeekConversation &conversation, qreal temperature = 1.0);
+    QPair<int, QString> create(const QString &model, DeepSeekConversation &conversation, const QVariantHash &params);
 
 private:
     QString rootUrl;
