@@ -39,7 +39,6 @@ QJsonObject Gemini_1_5::predict(const QString &content, const QJsonArray &functi
     conversion.setChatContent(content);
 
     QString systemRole = m_params.value(PREDICT_PARAM_SYSTEMROLE).toString();
-    qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
 
     if (!systemRole.isEmpty()) {
         qCDebug(logLLM) << "Gemini_1_5 Setting system role for prediction";
@@ -50,7 +49,7 @@ QJsonObject Gemini_1_5::predict(const QString &content, const QJsonArray &functi
     connect(this, &Gemini_1_5::aborted, &chatCompletion, &GeminiChatCompletion::requestAborted);
     connect(&chatCompletion, &GeminiChatCompletion::readyReadDeltaContent, this, &Gemini_1_5::onReadyReadChatDeltaContent);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, temperature);
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, m_params);
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
@@ -72,7 +71,7 @@ QPair<int, QString> Gemini_1_5::verify()
     GeminiChatCompletion chatCompletion(apiUrl(), m_accountProxy.account);
     connect(this, &Gemini_1_5::aborted, &chatCompletion, &GeminiChatCompletion::requestAborted);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion);
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, m_params);
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
