@@ -16,7 +16,7 @@ class GeminiChatCompletion : public BaseNetWork
 {
 public:
     GeminiChatCompletion(const QString &url, const AccountProxy &account);
-    QPair<int, QString> create(const QString &model, GeminiConversation &conversation, qreal temperature = 1.0);
+    QPair<int, QString> create(const QString &model, GeminiConversation &conversation, const QVariantHash &params);
 private:
     QString rootUrl;
 };
