@@ -15,7 +15,7 @@ public:
      * @param temperature
      * @return
      */
-    QJsonObject predict(const QString &conversation, const QJsonArray &functions, const QString &systemRole = "", qreal temperature = 1.0) override;
+    QJsonObject predict(const QString &conversation, const QJsonArray &functions) override;
     /**
      * @brief text2Image
      * @param prompt
