@@ -42,7 +42,7 @@ QPair<int, QString> LLMinModelHub::verify()
     UniversalChatCompletion chatCompletion(apiUrl(), m_accountProxy.account);
     connect(this, &UniversalAPI::aborted, &chatCompletion, &UniversalChatCompletion::requestAborted);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion);
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, m_params);
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
@@ -73,7 +73,6 @@ QJsonObject LLMinModelHub::predict(const QString &content, const QJsonArray &fun
     conversion.filterThink();
 
     QString systemRole = m_params.value(PREDICT_PARAM_SYSTEMROLE).toString();
-    qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
 
     if (!systemRole.isEmpty())
         conversion.setSystemData(systemRole);
@@ -82,7 +81,7 @@ QJsonObject LLMinModelHub::predict(const QString &content, const QJsonArray &fun
     connect(this, &LLMinModelHub::aborted, &chatCompletion, &UniversalChatCompletion::requestAborted);
     connect(&chatCompletion, &UniversalChatCompletion::readyReadDeltaContent, this, &LLMinModelHub::onReadyReadChatDeltaContent);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, temperature);
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, m_params);
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
