@@ -9,7 +9,7 @@ class AIChatCompletion : public AINetWork
 public:
     explicit AIChatCompletion(const AccountProxy &account);
 
-    QPair<int, QString> create(const QString &model, AIConversation &conversation, qreal temperature = 1.0);
+    QPair<int, QString> create(const QString &model, AIConversation &conversation, const QVariantHash &params);
 };
 
 #endif // AICHATCOMPLETION_H
