@@ -31,7 +31,7 @@ QPair<int, QString> OpenRouterAPI::verify()
     UniversalChatCompletion chatCompletion(apiUrl(), m_accountProxy.account);
     connect(this, &OpenRouterAPI::aborted, &chatCompletion, &UniversalChatCompletion::requestAborted);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion);
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, m_params);
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
@@ -53,7 +53,6 @@ QJsonObject OpenRouterAPI::predict(const QString &content, const QJsonArray &fun
     conversion.setFunctions(functions);
 
     QString systemRole = m_params.value(PREDICT_PARAM_SYSTEMROLE).toString();
-    qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
 
     if (!systemRole.isEmpty()) {
         qCDebug(logLLM) << "OpenRouterAPI Setting system role for prediction";
@@ -64,7 +63,7 @@ QJsonObject OpenRouterAPI::predict(const QString &content, const QJsonArray &fun
     connect(this, &OpenRouterAPI::aborted, &chatCompletion, &UniversalChatCompletion::requestAborted);
     connect(&chatCompletion, &UniversalChatCompletion::readyReadDeltaContent, this, &OpenRouterAPI::onReadyReadChatDeltaContent);
 
-    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, temperature);
+    QPair<int, QString> errorpair = chatCompletion.create(modelId(), conversion, m_params);
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
