@@ -37,7 +37,6 @@ QJsonObject UniversalAgentAPI::predict(const QString &content, const QJsonArray
     conversion.setFunctions(functions);
 
     QString systemRole = m_params.value(PREDICT_PARAM_SYSTEMROLE).toString();
-    qreal temperature = m_params.value(PREDICT_PARAM_TEMPERATURE, 1.0).toReal();
 
     if (!systemRole.isEmpty()) {
         qCDebug(logLLM) << "UniversalAgentAPI Setting system role for conversation";
@@ -48,7 +47,7 @@ QJsonObject UniversalAgentAPI::predict(const QString &content, const QJsonArray
     connect(this, &UniversalAgentAPI::aborted, &chatCompletion, &UniversalNetWork::requestAborted);
     connect(&chatCompletion, &UniversalNetWork::readyReadDeltaContent, this, &UniversalAgentAPI::onReadyReadChatDeltaContent);
 
-    QPair<int, QString> errorpair = chatCompletion.create(conversion, temperature, params());
+    QPair<int, QString> errorpair = chatCompletion.create(conversion, m_params, params());
     setLastError(errorpair.first);
     setLastErrorString(errorpair.second);
 
