@@ -17,15 +17,16 @@ QString UniversalNetWork::rootUrlPath() const
     return rootUrl;
 }
 
-QPair<int, QString> UniversalNetWork::create(AIConversation &conversation, qreal temperature, const QJsonObject &params)
+QPair<int, QString> UniversalNetWork::create(AIConversation &conversation, const QVariantHash &params , const QJsonObject &jparams)
 {
     QJsonObject dataObject;
     dataObject.insert("messages", conversation.getConversions());
-    dataObject.insert("temperature", qBound(0.01, temperature, 0.99));
+    if (params.contains("temperature"))
+        dataObject.insert("temperature", qBound(0.1, params.value("temperature").toDouble(), 0.9));
     dataObject.insert("stream", true);
 
-    for (const QString &key : params.keys())
-        dataObject.insert(key, params.value(key));
+    for (const QString &key : jparams.keys())
+        dataObject.insert(key, jparams.value(key));
 
     const QPair<int, QByteArray> &resultPairs = request(dataObject, "");
 
