@@ -16,7 +16,7 @@ class UniversalNetWork : public AINetWork
 public:
     UniversalNetWork(const QString &url, const AccountProxy &account);
     QString rootUrlPath() const override;
-    QPair<int, QString> create(AIConversation &conversation, qreal temperature = 1.0, const QJsonObject &params = {});
+    QPair<int, QString> create(AIConversation &conversation, const QVariantHash &params, const QJsonObject &jparams);
 private:
     QString rootUrl;
 };
