@@ -10,7 +10,6 @@
 #include "oscallcontext.h"
 
 #include <QFileInfo>
-#include <QDebug>
 #include <QDBusPendingCall>
 #include <QJsonDocument>
 #include <QJsonArray>
@@ -19,117 +18,21 @@
 #include <QDir>
 #include <DStandardPaths>
 #include <QDBusObjectPath>
+#include <QLoggingCategory>
 
-DeepinLauncher::DeepinLauncher(bool isLinglong,
-                               const QStringList &deskPaths,
-                               QObject *parent)
-    : QObject(parent)
-    , m_fIsLinglong(isLinglong)
+Q_DECLARE_LOGGING_CATEGORY(logOsControl)
+
+UOSAI_USE_NAMESPACE
+
+DeepinLauncher::DeepinLauncher(const QStringList &deskPaths, QObject *parent) : QObject(parent)
     , m_defaultDesktopPaths(deskPaths)
 {
-    QString deepinLauncherService;
-    QString deepinLauncherPath;
-    QString deepinLauncherInterface;
-
-    QString deepinStartManagerService;
-    QString deepinStartManagerPath;
-    QString deepinStartManagerInterface;
-
-    QString deepinMimeService;
-    QString deepinMimePath;
-    QString deepinMimeInterface;
-
-    QString deepinNewAppManagerService;
-    QString deepinNewAppManagerPath;
-    QString deepinNewAppManagerInterface;
-
-    QString deepinNewMimeService;
-    QString deepinNewMimePath;
-    QString deepinNewMimeInterface;
-
-    /*V23
-     *
-     * Show OS launcher:
-     * qdbus --literal org.deepin.dde.Launcher1
-     *      /org/deepin/dde/Launcher1
-     *      org.deepin.dde.Launcher1.Show
-     *
-     *
-     * Start application:
-     * qdbus --literal org.deepin.dde.StartManager1
-     *      /org/deepin/dde/StartManager1
-     *      org.deepin.dde.StartManager1.Launch
-     *          "/usr/share/applications/dde-computer.desktop"
-     *
-     * Mime service:
-     *  qdbus --literal org.deepin.dde.Mime1
-     *      /org/deepin/dde/Mime1
-     *      org.deepin.dde.Mime1.ListApps "x-scheme-handler/https"
-     *
-     * */
-    if (m_fIsLinglong) {
-        deepinLauncherService = QString("org.deepin.dde.Launcher1");
-        deepinLauncherPath = QString("/org/deepin/dde/Launcher1");
-        deepinLauncherInterface = deepinLauncherService;
-
-        deepinStartManagerService = QString("org.deepin.dde.StartManager1");
-        deepinStartManagerPath = QString("/org/deepin/dde/StartManager1");;
-        deepinStartManagerInterface = deepinStartManagerService;
-
-        deepinMimeService = QString("org.deepin.dde.Mime1");
-        deepinMimePath = QString("/org/deepin/dde/Mime1");;
-        deepinMimeInterface = deepinMimeService;
-
-        /*V23 new Application manager:
-         *
-         * qdbus --literal org.desktopspec.ApplicationManager1
-         *      /org/desktopspec/ApplicationManager1
-         *      org.desktopspec.ApplicationManager1.List
-         **/
-
-        deepinNewAppManagerService = QString("org.desktopspec.ApplicationManager1");
-        deepinNewAppManagerPath = QString("/org/desktopspec/ApplicationManager1");;
-        deepinNewAppManagerInterface = deepinNewAppManagerService;
-
-        m_v23NewAM.reset(
-            new QDBusInterface(
-                deepinNewAppManagerService,
-                deepinNewAppManagerPath,
-                deepinNewAppManagerInterface,
-                QDBusConnection::sessionBus(), this));
-        m_v23NewAM->setTimeout(m_callTimeout);
-
-        QString deepinNewMimeService = QString("org.desktopspec.ApplicationManager1");
-        QString deepinNewMimePath = QString("/org/desktopspec/ApplicationManager1/MimeManager1");;
-        QString deepinNewMimeInterface = QString("org.desktopspec.MimeManager1");
-
-        m_v23NewMIME.reset(
-            new QDBusInterface(
-                deepinNewMimeService,
-                deepinNewMimePath,
-                deepinNewMimeInterface,
-                QDBusConnection::sessionBus(), this));
-        m_v23NewMIME->setTimeout(m_callTimeout);
-    } else {
-        deepinLauncherService = QString("com.deepin.dde.Launcher");
-        deepinLauncherPath = QString("/com/deepin/dde/Launcher");
-        deepinLauncherInterface = deepinLauncherService;
-
-        deepinStartManagerService = QString("com.deepin.SessionManager");
-        deepinStartManagerPath = QString("/com/deepin/StartManager");;
-        deepinStartManagerInterface = QString("com.deepin.StartManager");
-
-        deepinMimeService = QString("com.deepin.daemon.Mime");
-        deepinMimePath = QString("/com/deepin/daemon/Mime");;
-        deepinMimeInterface = deepinMimeService;
-    }
-
     // Launcher interface
     m_oslauncher.reset(
         new QDBusInterface(
-            deepinLauncherService,
-            deepinLauncherPath,
-            deepinLauncherInterface,
+            deepinLancherService,
+            deepinLancherPath,
+            deepinLancherInterface,
             QDBusConnection::sessionBus(), this));
     m_oslauncher->setTimeout(m_callTimeout);
 
@@ -180,8 +83,7 @@ int DeepinLauncher::showLauncher()
         reply.waitForFinished();
 
         if (reply.isError()) {
-            qCritical() << "Show call failed:"
-                        << reply.error();
+            qCWarning(logOsControl) << "Show launcher failed - error:" << reply.error().message();
 
             if (QDBusError::UnknownMethod == reply.error().type()) {
                 errorCode = OSCallContext::NotImpl;
@@ -190,6 +92,7 @@ int DeepinLauncher::showLauncher()
             }
         }
     } else {
+        qCWarning(logOsControl) << "Launcher interface is invalid";
         errorCode = OSCallContext::NonService;
     }
 
@@ -198,27 +101,27 @@ int DeepinLauncher::showLauncher()
 
 int DeepinLauncher::launchDesktop(const QString &pathApp)
 {
+    qCDebug(logOsControl) << "Launching desktop application:" << pathApp;
     int errorCode = OSCallContext::NonError;
-
     QFileInfo appFile(pathApp);
-
     //Query the desktop file paths if only supply
     //xxx.desktop file
     if (!appFile.isAbsolute()) {
         QString deskPath = getAppDesktopFile(pathApp);
         appFile.setFile(deskPath);
+        qCDebug(logOsControl) << "Resolved desktop file path:" << deskPath;
     }
 
     if (!appFile.exists()) {
-        qCritical() << "Target file does not exist: " << pathApp;
+        qCWarning(logOsControl) << "Target file does not exist:" << pathApp;
         errorCode = OSCallContext::AppNotFound;
-        goto EXIT_ENTERY;
+        return errorCode;
     }
 
     if (appFile.suffix() != "desktop") {
-        qCritical() << "Target file's is not *.desktop: " << pathApp;
+        qCWarning(logOsControl) << "Target file is not a desktop file:" << pathApp;
         errorCode = OSCallContext::AppNotFound;
-        goto EXIT_ENTERY;
+        return errorCode;
     }
 
     /*
@@ -233,19 +136,50 @@ int DeepinLauncher::launchDesktop(const QString &pathApp)
      *      com.deepin.StartManager.Launch "<abs path>/xxx.desktop"
      * */
     //Try launch app use v23's new application manager
-    if (m_fIsLinglong) {
-        if (m_v23NewAM->isValid()) {
-            errorCode = launchDesktopWithV23AM(appFile.filePath());
+#ifdef COMPILE_ON_V23
+    QScopedPointer<QDBusInterface> appAM;
+    QString appPath;
+    QString appId = getAppIdFromAbsolutePath(pathApp);
+    appPath = escapeToObjectPath(appId);
+    /* V23 new AM:
+     *
+     * qdbus --literal org.desktopspec.ApplicationManager1
+     *      /org/desktopspec/ApplicationManager1/<appPath>
+     *      org.desktopspec.ApplicationManager1.Application.Launch
+     *       "", [], {}
+     *
+     **/
+    appAM.reset(new QDBusInterface(
+                       deepinStartManagerService,
+                       QString(deepinStartManagerPath) + QString("/%1").arg(appPath),
+                       deepinStartManagerInterface,
+                       QDBusConnection::sessionBus(), this));
+    if (appAM->isValid()) {
+        QList<QVariant> argumentList;
+        argumentList << QVariant::fromValue<QString>(QString(""))
+                     << QVariant::fromValue<QStringList>(QStringList(""))
+                     << QVariant::fromValue<QVariantMap>(QVariantMap());
 
-            //If launch ok with new AM, just exit.
-            // else try to use old start manager.
-            if (errorCode == OSCallContext::NonError) {
-                goto EXIT_ENTERY;
-            }
-        } else {
-            qWarning() << "V23 new application service isn't avaiable.";
+        auto reply = appAM->asyncCallWithArgumentList(
+                         QStringLiteral("Launch"), argumentList);
+        reply.waitForFinished();
+
+        if (reply.isError()) {
+            qCWarning(logOsControl) << "Failed to launch app with V23 manager - path:" << pathApp
+                                  << "error:" << reply.error().message();
+            errorCode = OSCallContext::AppStartFailed;
         }
+
+    } else {
+        qCWarning(logOsControl) << "V23 application manager interface is invalid";
+        errorCode = OSCallContext::NonService;
     }
+    //If launch ok with new AM, just exit.
+    // else try to use old start manager.
+    if (errorCode == OSCallContext::NonError) {
+        return errorCode;
+    }
+#endif
 
     if (m_osStartManager->isValid()) {
         QList<QVariant> argumentList;
@@ -257,8 +191,8 @@ int DeepinLauncher::launchDesktop(const QString &pathApp)
         reply.waitForFinished();
 
         if (reply.isError()) {
-            qCritical() << "Launch call failed:" << appFile.filePath()
-                        << " " << reply.error();
+            qCWarning(logOsControl) << "Launch failed with start manager - path:" << appFile.filePath()
+                                  << "error:" << reply.error().message();
 
             if (QDBusError::UnknownMethod == reply.error().type()) {
                 errorCode = OSCallContext::NotImpl;
@@ -268,24 +202,20 @@ int DeepinLauncher::launchDesktop(const QString &pathApp)
         } else {
             bool success = reply.reply().arguments().at(0).toBool();
             if (!success) {
-                qCritical() << "Start the " << pathApp
-                            << " failed, Status: "
-                            << success;
+                qCWarning(logOsControl) << "Application start failed - path:" << pathApp;
                 errorCode = OSCallContext::AppStartFailed;
             }
         }
     } else {
-        qCritical() << "m_osStartManager is invalid!";
+        qCWarning(logOsControl) << "Start manager interface is invalid";
         errorCode = OSCallContext::NonService;
     }
-
-EXIT_ENTERY:
-
     return errorCode;
 }
 
 QString DeepinLauncher::getAppDesktopFile(const QString &DesktopName)
 {
+    qCDebug(logOsControl) << "Getting desktop file for:" << DesktopName;
     QString appDesktopFile;
 
     foreach (auto path, m_defaultDesktopPaths) {
@@ -293,6 +223,7 @@ QString DeepinLauncher::getAppDesktopFile(const QString &DesktopName)
 
         if (f.isFile() && f.exists()) {
             appDesktopFile = f.filePath();
+            qCDebug(logOsControl) << "Found desktop file:" << appDesktopFile;
             break;
         }
     }
@@ -302,48 +233,76 @@ QString DeepinLauncher::getAppDesktopFile(const QString &DesktopName)
 
 int DeepinLauncher::launchDefault(const QString &mineType)
 {
+    qCDebug(logOsControl) << "Launching default application for mime type:" << mineType;
     int errorCode = OSCallContext::NonError;
 
-    if (m_fIsLinglong) {
-        if (m_v23NewMIME->isValid()) {
-            QList<QVariant> argumentList;
-            argumentList << QVariant::fromValue<QString>(mineType);
-            auto reply = m_v23NewMIME->asyncCallWithArgumentList(
-                             QStringLiteral("queryDefaultApplication"), argumentList);
-
-            reply.waitForFinished();
-
-            if (reply.isError()) {
-                qCritical() << "Failed (NewMIME) to get default apps:" << mineType
-                            << " Error message: " << reply.error();
-            } else {
-                QString mimeType = reply.reply().arguments().value(0).toString();
-                QString defaultAppPath = reply.reply().arguments().value(1).value<QDBusObjectPath>().path();
-
-                errorCode = launchDesktopWithV23AM(defaultAppPath, true);
-
-                //If launch ok with new AM, just exit.
-                // else try to use old start manager.
-                if (errorCode == OSCallContext::NonError) {
-                    goto EXIT_ENTERY;
-                }
-            }
+#ifdef COMPILE_ON_V23
+    QScopedPointer<QDBusInterface> appMime;
+    appMime.reset(
+        new QDBusInterface(
+            deepinNewMimeService,
+            deepinNewMimePath,
+            deepinNewMimeInterface,
+            QDBusConnection::sessionBus(), this));
+    if (appMime->isValid()) {
+        QList<QVariant> argumentList;
+        argumentList << QVariant::fromValue<QString>(mineType);
+        auto reply = appMime->asyncCallWithArgumentList(
+                         QStringLiteral("queryDefaultApplication"), argumentList);
+        reply.waitForFinished();
+        if (reply.isError()) {
+            qCWarning(logOsControl) << "Failed to get default app with V23 mime service - type:" << mineType
+                                  << "error:" << reply.error().message();
         } else {
-            qWarning() << "V23 new application service isn't avaiable.";
-        }
-    }
+            QString mimeType = reply.reply().arguments().value(0).toString();
+            QString defaultAppPath = reply.reply().arguments().value(1).value<QDBusObjectPath>().path();
+            
+            qCDebug(logOsControl) << "Got default app from V23 mime service - type:" << mimeType
+                                << "path:" << defaultAppPath;
+            
+            QScopedPointer<QDBusInterface> appAM;
+            appAM.reset(new QDBusInterface(
+                               deepinStartManagerService,
+                               defaultAppPath,
+                               deepinStartManagerInterface,
+                               QDBusConnection::sessionBus(), this));
+            if (appAM->isValid()) {
+                QList<QVariant> argumentList;
+                argumentList << QVariant::fromValue<QString>(QString(""))
+                             << QVariant::fromValue<QStringList>(QStringList(""))
+                             << QVariant::fromValue<QVariantMap>(QVariantMap());
 
+                auto reply = appAM->asyncCallWithArgumentList(
+                                 QStringLiteral("Launch"), argumentList);
+                reply.waitForFinished();
+                if (reply.isError()) {
+                    qCWarning(logOsControl) << "Failed to launch default app - path:" << defaultAppPath
+                                          << "error:" << reply.error().message();
+                    errorCode = OSCallContext::AppStartFailed;
+                }
+            } else {
+                qCWarning(logOsControl) << "V23 application manager interface is invalid";
+                errorCode = OSCallContext::NonService;
+            }
+            //If launch ok with new AM, just exit.
+            // else try to use old start manager.
+            if (errorCode == OSCallContext::NonError) {
+                return errorCode;
+            }
+        }
+    } else {
+        qCDebug(logOsControl) << "V23 new application service is not available";
+    }
+#endif
     if (m_osMime->isValid()) {
         QList<QVariant> argumentList;
         argumentList << QVariant::fromValue<QString>(mineType);
         auto reply = m_osMime->asyncCallWithArgumentList(
                          QStringLiteral("GetDefaultApp"), argumentList);
-
         reply.waitForFinished();
-
         if (reply.isError()) {
-            qCritical() << "Failed to get default apps:" << mineType
-                        << " Error message: " << reply.error();
+            qCWarning(logOsControl) << "Failed to get default app - type:" << mineType
+                                  << "error:" << reply.error().message();
 
             if (QDBusError::UnknownMethod == reply.error().type()) {
                 errorCode = OSCallContext::NotImpl;
@@ -359,7 +318,7 @@ int DeepinLauncher::launchDefault(const QString &mineType)
             QJsonObject defaultAppObj = jsonApp.object();
 
             if (jsonApp.isNull() || !jsonApp.isObject()) {
-                qCritical() << "Parse default app json error:" << defaultAppInfo;
+                qCWarning(logOsControl) << "Failed to parse default app JSON:" << defaultAppInfo;
                 errorCode = OSCallContext::AppStartFailed;
             } else {
                 QString strDefaultApp = defaultAppObj["Id"].toString();
@@ -368,12 +327,10 @@ int DeepinLauncher::launchDefault(const QString &mineType)
             }
         }
     } else {
-        qCritical() << "m_osMime is invalid!";
+        qCWarning(logOsControl) << "Mime interface is invalid";
         errorCode = OSCallContext::NonService;
     }
 
-EXIT_ENTERY:
-
     return errorCode;
 }
 
@@ -441,6 +398,7 @@ QString DeepinLauncher::escapeToObjectPath(const QString &str)
             ret.replace(c, QString{R"(_%1)"}.arg(hexStr));
         }
     }
+    qCDebug(logOsControl) << "Escaped object path:" << ret;
     return ret;
 }
 
@@ -454,15 +412,18 @@ QString DeepinLauncher::unescapeFromObjectPath(const QString &str)
             i += 2;
         }
     }
+    qCDebug(logOsControl) << "Unescaped object path:" << ret;
     return ret;
 }
 
 QString DeepinLauncher::getAppIdFromAbsolutePath(const QString &path)
 {
+    qCDebug(logOsControl) << "Getting app ID from path:" << path;
     static QString desktopSuffix{u8".desktop"};
     const auto &appDirs = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
     if (!path.endsWith(desktopSuffix) or
     !std::any_of(appDirs.cbegin(), appDirs.constEnd(), [&path](const QString & dir) { return path.startsWith(dir); })) {
+        qCDebug(logOsControl) << "Invalid desktop file path";
         return {};
     }
 
@@ -474,6 +435,7 @@ QString DeepinLauncher::getAppIdFromAbsolutePath(const QString &path)
 #endif
     auto location = std::find(components.cbegin(), components.cend(), "applications");
     if (location == components.cend()) {
+        qCDebug(logOsControl) << "No applications directory found in path";
         return {};
     }
 
@@ -482,68 +444,6 @@ QString DeepinLauncher::getAppIdFromAbsolutePath(const QString &path)
         tmpLocation << *it;
 
     auto appId = tmpLocation.join('-');
+    qCDebug(logOsControl) << "Extracted app ID:" << appId;
     return appId;
 }
-
-int DeepinLauncher::launchDesktopWithV23AM(const QString &pathApp, bool isAppPath)
-{
-    int errorCode = OSCallContext::NonError;
-
-    QScopedPointer<QDBusInterface> v23AppAM;
-
-    QString appPath;
-
-    if (!isAppPath) {
-        QString appId = getAppIdFromAbsolutePath(pathApp);
-        appPath = escapeToObjectPath(appId);
-    }
-
-    /* V23 new AM:
-     *
-     * qdbus --literal org.desktopspec.ApplicationManager1
-     *      /org/desktopspec/ApplicationManager1/<appPath>
-     *      org.desktopspec.ApplicationManager1.Application.Launch
-     *       "", [], {}
-     *
-     **/
-    QString v23AppManagerService = QString("org.desktopspec.ApplicationManager1");
-    QString v23AppManagerPath = isAppPath ? pathApp :
-                                QString("/org/desktopspec/ApplicationManager1/%1").arg(appPath);
-    QString v23AppManagerInterface = QString("org.desktopspec.ApplicationManager1.Application");
-
-    qInfo() << "launchDesktopWithV23AM->"
-            << v23AppManagerService
-            << v23AppManagerPath
-            << v23AppManagerInterface;
-
-    if (!v23AppManagerPath.isEmpty()) {
-        v23AppAM.reset(new QDBusInterface(
-                           v23AppManagerService,
-                           v23AppManagerPath,
-                           v23AppManagerInterface,
-                           QDBusConnection::sessionBus(), this));
-        if (v23AppAM->isValid()) {
-
-            QList<QVariant> argumentList;
-            argumentList << QVariant::fromValue<QString>(QString(""))
-                         << QVariant::fromValue<QStringList>(QStringList(""))
-                         << QVariant::fromValue<QVariantMap>(QVariantMap());
-
-            auto reply = v23AppAM->asyncCallWithArgumentList(
-                             QStringLiteral("Launch"), argumentList);
-
-            reply.waitForFinished();
-
-            if (reply.isError()) {
-                qCritical() << "Failed to lauch app:" << pathApp
-                            << " Error message: " << reply.error();
-                errorCode = OSCallContext::AppStartFailed;
-            }
-
-        } else {
-            errorCode = OSCallContext::NonService;
-        }
-    }
-
-    return errorCode;
-}
