@@ -43,7 +43,7 @@ TextAuditResult UosSimpleTas::doTextAuditing(const QByteArray &data)
     loop.setHttpOutTime(15000);
     loop.exec();
 
-    TextAuditResult txtResult;
+    TextAuditResult txtResult{};
     QNetworkReply::NetworkError netReplyError;
     bool isAuthError = httpAccessManager->isAuthenticationRequiredError();
     if (isAuthError)
