@@ -39,6 +39,9 @@ namespace  uos_ai {
 #define LLM_GROUP "uos-ai-assistant.llm"
 #define LLM_UOSAIRAG "aiRagVersion"
 
+#define MCP_GROUP "uos-ai-assistant.mcp"
+#define MCP_ENABLED_LIST "enabledList"
+
 class DConfigManagerPrivate;
 class DConfigManager : public QObject
 {
