@@ -27,6 +27,11 @@ enum EventID {
     SCREENSHOT_CLICKED   = 1001600012,
     ASSISTANT_CHAT_TYPE  = 1001600013,
     MCP_CHAT             = 1001600014,
+    CHATWINDOW_START     = 1001600015,
+    MODEL                = 1001600016,
+    KNOWLEDGE_FUNCTION   = 1001600017,
+    KNOWLEDGE_FILE_TYPE  = 1001600018,
+    KNOWLEDGE_FILE_NUMBER= 1001600019,
 };
 
 class BasicPoint
