@@ -9,6 +9,7 @@
 #include "../private/writertextedit.h"
 #include "../private/continuebutton.h"
 #include "../private/topdialog.h"
+#include "../private/languageComboDelegate.h"
 #include "util.h"
 #include "utils/esystemcontext.h"
 #include "private/baseclipboard.h"
@@ -76,6 +77,8 @@ int AiQuickDialog::kTargetLanguageIdx = -1;
 
 bool AiQuickDialog::kIsFirstTranslate = true;
 
+LanguageComboDelegate *m_languageComboBoxDelegate = nullptr;
+
 bool AiQuickDialog::almostAllEnglish(QString text) {
     if (text.isEmpty()) {
         return true;
@@ -225,6 +228,20 @@ void AiQuickDialog::initUi()
     m_queryLayout->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     m_queryLayout->addWidget(m_querySep);
     m_queryLayout->addWidget(m_queryTextEdit);
+    m_querySep->setVisible(true);
+    m_queryTextEdit->setVisible(true);
+
+    m_inOCRMovie = new QMovie(":assets/images/light/light-loading.gif");
+    m_inOCRLabel = new DLabel(this);
+    m_inOCRLabel->setMovie(m_inOCRMovie);
+    // original size 800x83
+    int inOCRWidth = this->width() - 30;
+    float inOCRRatio = 800.0F / inOCRWidth;
+    int inOCRHeight = 38; //static_cast<int>(83.0F / inProgressRatio);
+    m_inOCRLabel->setFixedSize(inOCRWidth, inOCRHeight);
+    m_inOCRLabel->setScaledContents(true);
+    m_inOCRLabel->setVisible(false);
+    m_queryLayout->addWidget(m_inOCRLabel);
 
     m_queryHSep = new DWidget(this);
     m_queryHSep->setFixedSize(this->width() - 30, 1);
@@ -412,6 +429,11 @@ void AiQuickDialog::initUi()
     m_languageComboBox->setCurrentIndex(0);
     m_languageComboBox->setVisible(false);
 
+    m_languageComboBoxDelegate = new LanguageComboDelegate(this);
+    // Set custom item delegate to show items with two lines: normal size and smaller size
+    m_languageComboBox->setItemDelegate(m_languageComboBoxDelegate);
+    m_languageComboBoxDelegate->setCurrentIndex(0);
+
     DPalette boxPalette = m_autoComboBox->palette();
     boxPalette.setColor(DPalette::ButtonText, QColor(0, 0, 0, int(255 * 0.7)));
     m_autoComboBox->setPalette(boxPalette);
@@ -453,7 +475,7 @@ void AiQuickDialog::initUi()
     qCDebug(logWordWizard) << "m_replyTextEditMax:" << m_replyTextEditMax;
 
     // menu
-    m_menu = new DMenu(this);
+    m_menu = new CustomDMenu(this);
     m_searchAction = new QAction(tr("Search"), this);
     m_explainAction = new QAction(tr("Explain"), this);
     m_summarizeAction = new QAction(tr("Summary"), this);
@@ -530,6 +552,7 @@ void AiQuickDialog::initUi()
                 if (m_knowledgeAction) {
                     m_showActions.insert(m_knowledgeAction);
                     m_knowledgeAction->setData(QVariant::fromValue(func));
+                    updateKnowledgeActionEnabled();
                 }
                 break;
             default:
@@ -578,6 +601,7 @@ void AiQuickDialog::initConnect()
         }
 
         kTargetLanguageIdx = index;
+        m_languageComboBoxDelegate->setCurrentIndex(index);
         DConfigManager::instance()->setValue(AIQUICK_GROUP, AIQUICK_TRANSLATE_TARGET_LANGUAGE, kTargetLanguageIdx);
         if (kTargetLanguageIdx >= 0 && kTargetLanguageIdx < kLanguageList.size()) {
             if (kIsFirstTranslate && kTargetLanguageIdx != LANGUAGE_TYPE_SIMPLIFIED_CHINESE && kTargetLanguageIdx != LANGUAGE_TYPE_ENGLISH) {
@@ -623,7 +647,7 @@ void AiQuickDialog::initConnect()
     connect(&WizardWrapper::instance(), &WizardWrapper::signalEscEvent, this, &AiQuickDialog::close);
 }
 
-void AiQuickDialog::setQuery(int type, QString query, QPoint pos, bool isCustom)
+void AiQuickDialog::setQuery(int type, QString query, QPoint pos, bool isCustom, const QString &imagePath)
 {
     qCInfo(logWordWizard) << "setQuery - type:" << type << "query:" << query << "pos:" << pos << "isCustom:" << isCustom;
     m_queryType = type;
@@ -677,13 +701,17 @@ void AiQuickDialog::setQuery(int type, QString query, QPoint pos, bool isCustom)
         qCInfo(logWordWizard) << "Custom function name:" << func.name;
         this->setCustomQueryType(func);
     }
-    m_queryTextEdit->setFullText(m_query);
-
-    // query
-    m_query.replace("￼", " ");
-
+    updateKnowledgeActionEnabled();
     this->syncLlmAccount();
-    this->sendAiRequst();
+
+    if(imagePath != "") {
+       runOCRProcessByPath(type, isCustom, imagePath);
+    } else {
+        m_queryTextEdit->setFullText(m_query);
+        // query
+        m_query.replace("￼", " ");
+        this->sendAiRequst();
+    }
 }
 
 void AiQuickDialog::showEvent(QShowEvent *event)
@@ -870,7 +898,7 @@ void AiQuickDialog::onBtClicked()
     }
 
     if (sender() == m_replaceBt) {
-        qCInfo(logWordWizard) << "Replace button clicked, isFirstFill:" << m_isFirstFill 
+        qCInfo(logWordWizard) << "Replace button clicked, isFirstFill:" << m_isFirstFill
                             << "isWritable:" << m_isWritable;
         if (m_isFirstFill) { // 第一次使用填充功能，提醒用户重启输入法服务
             TopDialog dlg(this);
@@ -978,7 +1006,7 @@ void AiQuickDialog::onMenuTriggered(QAction *action)
         qCInfo(logWordWizard) << "Custom function name:" << func.name;
         this->setCustomQueryType(func);
     }
-    
+
     this->sendAiRequst();
     this->asyncAdjustSize();
 }
@@ -1128,6 +1156,11 @@ void AiQuickDialog::onUpdateSystemTheme()
             m_inProgressMovie->stop();
             m_inProgressMovie->start();
         }
+        m_inOCRMovie->setFileName(":assets/images/light/light-loading.gif");
+        if (m_inOCRMovie->state() == QMovie::Running) {
+            m_inOCRMovie->stop();
+            m_inOCRMovie->start();
+        }
     } else {
         DPalette titlePalette = m_titleBt->palette();
         titlePalette.setColor(DPalette::ButtonText, QColor(255, 255, 255, 178));
@@ -1182,6 +1215,11 @@ void AiQuickDialog::onUpdateSystemTheme()
             m_inProgressMovie->stop();
             m_inProgressMovie->start();
         }
+        m_inOCRMovie->setFileName(":assets/images/light/dark-loading.gif");
+        if (m_inOCRMovie->state() == QMovie::Running) {
+            m_inOCRMovie->stop();
+            m_inOCRMovie->start();
+        }
     }
     m_themeType = themeType;
     update();
@@ -1317,6 +1355,7 @@ void AiQuickDialog::setQueryType(int type)
         }
         m_readBt->setVisible(isReadAloudSupported());
         m_languageComboBox->setCurrentIndex(kTargetLanguageIdx);
+        m_languageComboBoxDelegate->setCurrentIndex(kTargetLanguageIdx);
         m_systemPrompt = QString(tr("Translate this passage into %1 and give me a clear result directly.\ntext：")).arg(m_languagePromptList[kTargetLanguageIdx]);
         break;
     case WordWizard::WIZARD_TYPE_RENEW:
@@ -1532,7 +1571,7 @@ void AiQuickDialog::continueDialog()
     dialogContent.insert("content", m_reply);
     dialogContent.insert("chatType", ChatAction::ChatTextPlain);
     displayContentArray.append(dialogContent);
-    
+
     answer.chatType       = ChatAction::ChatTextPlain;
     answer.reqId          = m_reqId;
     answer.content        = m_reply;
@@ -1545,6 +1584,8 @@ void AiQuickDialog::continueDialog()
     answer.errInfo        = "{\"info\":\"\", \"exec\":\"\"}";
     answer.isRetry        = false;
     answer.extention      = "[]";
+    answer.knowledgeSearchStatus = false;
+
     conv.answers.append(answer);
 
     if (EAiExec()->showChatWindow()) { // 等待前端渲染完成后再传，下一步会接收信号判断是否渲染完成
@@ -1696,7 +1737,7 @@ void AiQuickDialog::enableReplyFunBt(bool isTrue)
 void AiQuickDialog::setReplyPartVisible(bool isTrue)
 {
     qCDebug(logWordWizard) << "Setting reply part visibility:" << isTrue;
-    
+
 #ifdef COMPILE_ON_V25
     m_isWritable = m_isWritable || WordWizard::fcitxWritable();//尽可能保持m_isWritable为true
 #endif
@@ -1718,5 +1759,226 @@ bool AiQuickDialog::isReadAloudSupported() const
     // 朗读功能，只能朗读中文和英语
     return kTargetLanguageIdx == LANGUAGE_TYPE_SIMPLIFIED_CHINESE
            // || kTargetLanguageIdx == LANGUAGE_TYPE_TRADITIONAL_CHINESE  // 繁体中文暂不支持朗读
-           || kTargetLanguageIdx == LANGUAGE_TYPE_ENGLISH;
+            || kTargetLanguageIdx == LANGUAGE_TYPE_ENGLISH;
+}
+
+void AiQuickDialog::runOCRProcessByPath(int type, bool isCustom, const QString &imagePath)
+{
+    if (imagePath.isEmpty()) {
+        qCWarning(logWordWizard) << "OCR process: Empty image path list";
+        return;
+    }
+
+    if (false) {
+        QString assisListJson = EAiExec()->queryAssistantList();
+        QJsonDocument jsonDoc = QJsonDocument::fromJson(assisListJson.toUtf8());
+        QJsonArray jsonArr = jsonDoc.array();
+        for (int i = 0; i < jsonArr.size(); i++) {
+            QJsonObject infoJson = jsonArr[i].toObject();
+            if (infoJson["displayname"] == "UOS AI") {
+                EAiExec()->setCurrentAssistantId(infoJson["id"].toString());
+                break;
+            }
+        }
+    }
+
+    // 每次发起请求时，复位错误码
+    m_curErr = ERROR_TYPE_NONE;
+    EAiExec()->cancelAiRequst(m_reqId);
+    EAiExec()->clearAiRequest(this);
+
+    m_replyCacheMutex.lock();
+    m_replyCache.clear();
+    m_replyCacheIdx = 0;
+    m_replyCacheMutex.unlock();
+
+    if (!m_reply.isEmpty()) {
+        m_replyBak = m_reply;
+    }
+    m_reply.clear();
+    m_replyTextEdit->clear();
+    m_isReplyEditCursorEnd = true;
+
+    m_querySep->setVisible(false);
+    m_queryTextEdit->setVisible(false);
+    m_inOCRLabel->setVisible(true);
+    m_inOCRMovie->start();
+
+    m_replyTextEdit->setVisible(false);
+    m_inProgressLabel->setVisible(true);
+    m_inProgressMovie->start();
+
+    // 每次发起请求时，隐藏下半部分控件
+    this->setReplyPartVisible(false);
+    this->enableReplyFunBt(false);
+    this->asyncAdjustSize();
+
+    qCInfo(logWordWizard) << "Starting OCR process for images:" << imagePath;
+
+    // 创建 QProcess 实例
+    QProcess *ocrProcess = new QProcess(this);
+
+    QStringList arguments;
+
+    // 添加图片路径参数（用逗号分隔）
+    arguments << "--images" << imagePath;
+
+    // 添加语言参数
+    arguments << "--language" << "zh-Hans_en";
+
+    // 设置进程完成时的处理
+    connect(ocrProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+            [this, ocrProcess, type, isCustom](int exitCode, QProcess::ExitStatus exitStatus) {
+        Q_UNUSED(exitStatus)
+
+        qCInfo(logWordWizard) << "OCR process finished with exit code:" << exitCode;
+
+        // 读取进程输出并收集结果
+        QString allResults;
+        QByteArray outputData = ocrProcess->readAllStandardOutput();
+        QStringList lines = QString::fromUtf8(outputData).split('\n');
+
+        for (const QString &line : lines) {
+            if (line.trimmed().isEmpty()) continue;
+
+            // 解析 JSON 输出
+            QJsonParseError error;
+            QJsonDocument doc = QJsonDocument::fromJson(line.toUtf8(), &error);
+
+            if (error.error != QJsonParseError::NoError) {
+                qCWarning(logWordWizard) << "Failed to parse OCR output JSON:" << error.errorString();
+                continue;
+            }
+
+            QJsonObject obj = doc.object();
+            QString resultType = obj["type"].toString();
+
+            if (resultType == "single_result") {
+                // 单个图片结果
+                QJsonObject data = obj["data"].toObject();
+                bool success = data["success"].toBool();
+                QString result = data["result"].toString();
+
+                if (success) {
+                    qCInfo(logWordWizard) << "OCR result :" << result;
+                    if (!allResults.isEmpty()) {
+                        allResults += "\n\n";
+                    }
+                    allResults += result;
+                } else {
+                    QString errorMsg = data["error"].toString();
+                    qCWarning(logWordWizard) << "OCR failed :" << errorMsg;
+                }
+            }
+        }
+
+        qCInfo(logWordWizard) << "OCR process completed, returning accumulated results";
+
+        if (allResults != "") {
+            m_query = allResults;
+            m_systemPrompt += m_query;
+            m_query.replace("￼", " ");
+        } else {
+            m_query = tr("No text recognized.");
+            m_replyTextEdit->setVisible(true);
+            m_inProgressLabel->setVisible(false);
+            m_inProgressMovie->stop();
+        }
+
+        m_querySep->setVisible(true);
+        m_queryTextEdit->setVisible(true);
+        m_inOCRLabel->setVisible(false);
+        m_inOCRMovie->stop();
+        m_queryTextEdit->setFullText(m_query);
+
+        // 规避偶现的AI请求卡住UI线程，至少也要让dialog先show出来
+        if (allResults != "") {
+            QTimer::singleShot(100, this, [&] {
+                qCInfo(logWordWizard) << "Sending AI request - model:" << m_modelInfo << "query:" << m_systemPrompt;
+                m_reqId = EAiExec()->sendWordWizardRequest(m_modelId, m_systemPrompt, this, QString("onModelReply"));
+            });
+        }
+        // 清理进程对象防止内存泄漏
+        ocrProcess->deleteLater();
+    });
+
+    // 设置进程错误处理
+    connect(ocrProcess, &QProcess::errorOccurred,
+            [this, ocrProcess](QProcess::ProcessError error) {
+        qCWarning(logWordWizard) << "OCR process error occurred:" << error;
+
+        // 出错时恢复UI状态
+        m_querySep->setVisible(true);
+        m_queryTextEdit->setVisible(true);
+        m_inOCRLabel->setVisible(false);
+        m_inOCRMovie->stop();
+
+        m_query = tr("No text recognized.");
+        m_replyTextEdit->setVisible(true);
+        m_inProgressLabel->setVisible(false);
+        m_inProgressMovie->stop();
+        m_queryTextEdit->setFullText(m_query);
+
+        // 清理进程对象防止内存泄漏
+        ocrProcess->deleteLater();
+    });
+
+    // 设置标准错误输出读取处理
+    connect(ocrProcess, &QProcess::readyReadStandardError,
+            [this, ocrProcess]() {
+        QByteArray data = ocrProcess->readAllStandardError();
+        QString errorOutput = QString::fromUtf8(data).trimmed();
+        if (!errorOutput.isEmpty()) {
+            // 过滤掉一些常见的非关键警告信息
+            if (!errorOutput.contains("QML") &&
+                    !errorOutput.contains("libpng warning") &&
+                    !errorOutput.contains("deprecated")) {
+                qCWarning(logWordWizard) << "OCR process error output:" << errorOutput;
+            } else {
+                qCDebug(logWordWizard) << "OCR process debug output:" << errorOutput;
+            }
+        }
+    });
+
+    // 设置 OCR 进程和参数（调试的时候可以手动切换到build路径）
+    QString program = "/usr/lib/uos-ai-assistant/uos-ai-ocr-process";
+
+    qCInfo(logWordWizard) << "Starting OCR process with program:" << program
+                     << "arguments:" << arguments;
+
+    // 启动进程（非阻塞方式）
+    ocrProcess->start(program, arguments);
+
+    // 检查进程是否启动成功（非阻塞方式）
+    if (!ocrProcess->waitForStarted(50000)) { // 5 秒超时
+        qCWarning(logWordWizard) << "Failed to start OCR process:" << ocrProcess->errorString();
+
+        // 出错时恢复UI状态
+        m_querySep->setVisible(true);
+        m_queryTextEdit->setVisible(true);
+        m_inOCRLabel->setVisible(false);
+        m_inOCRMovie->stop();
+
+        m_query = tr("No text recognized.");
+        m_replyTextEdit->setVisible(true);
+        m_inProgressLabel->setVisible(false);
+        m_inProgressMovie->stop();
+        m_queryTextEdit->setFullText(m_query);
+
+        ocrProcess->deleteLater();
+        return;
+    }
+
+    qCInfo(logWordWizard) << "OCR process started successfully";
+}
+
+void AiQuickDialog::updateKnowledgeActionEnabled()
+{
+    if (!m_knowledgeAction)
+        return;
+
+    bool enabled = m_query.length() >= 10;
+    QString tooltip = enabled ? "" : tr("The added content must be more than 10 words");
+    m_knowledgeAction->setEnabled(enabled);
+    m_knowledgeAction->setToolTip(tooltip);
 }
