@@ -9,7 +9,6 @@
 #include "../wordwizard.h"
 #include "../private/transbutton.h"
 #include "../private/querytextedit.h"
-
 #include <QVariant>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -27,6 +26,9 @@
 #include <DWindowCloseButton>
 #include <DComboBox>
 
+namespace uos_ai {
+    class CustomDMenu;
+}
 class AiQuickDialog : public DAbstractDialog
 {
     Q_OBJECT
@@ -70,7 +72,7 @@ public:
      * @param query 文本
      * @param pos 显示位置，上方中心点
      */
-    void setQuery(int type, QString query, QPoint pos, bool isCustom);
+    void setQuery(int type, QString query, QPoint pos, bool isCustom, const QString &imagePath = "");
     void setQuerySepHeight(int height);
     void showToast(const QString &message);
     void copyText(const QString &text);
@@ -172,6 +174,12 @@ private:
      */
     bool isReadAloudSupported() const;
 
+    void updateKnowledgeActionEnabled();
+    /**
+     * @brief 启动新process进行ocr识别，将结果发送给大模型
+     */
+    void runOCRProcessByPath(int type, bool isCustom, const QString &imagePath);
+
 private slots:
     void onBtClicked();
     void onMenuTriggered(QAction *action);
@@ -213,6 +221,8 @@ private:
     DPushButton *m_cancelBt         = nullptr;
     DLabel *m_inProgressLabel       = nullptr;
     QMovie *m_inProgressMovie       = nullptr;
+    DLabel *m_inOCRLabel            = nullptr;
+    QMovie *m_inOCRMovie            = nullptr;
     DPushButton *m_readBt           = nullptr;
     DPushButton *m_replaceBt        = nullptr;
     DWidget *m_replySep1            = nullptr;
@@ -237,7 +247,7 @@ private:
     volatile bool m_isWebviewOk = true;
 
     // menu
-    DMenu *m_menu              = nullptr;
+    uos_ai::CustomDMenu *m_menu = nullptr;
     QAction *m_searchAction    = nullptr;
     QAction *m_explainAction   = nullptr;
     QAction *m_summarizeAction = nullptr;
@@ -285,5 +295,4 @@ private:
     QList<uos_ai::CustomFunction> m_customFunctionList;
     QSet<QAction *> m_showActions;
 };
-
 #endif // AIQUICKDIALOG_H
