@@ -13,6 +13,8 @@ class BaseMonitor : public QThread
 public:
     static BaseMonitor *instance();
     virtual QString getCurApp() { return ""; }
+    virtual int getCurPid() { return 0; }
+    virtual QString getAppByPid(int pid) { return ""; }
 
 protected:
     explicit BaseMonitor(QObject *parent = nullptr);
