@@ -146,6 +146,7 @@ void xEventMonitorPrivate::handleRecordEvent(XRecordInterceptData *data)
         switch (event->u.u.type) {
         case ButtonPress:
             q->m_curApp = getWindowName(getSubwindow(DefaultRootWindow(windowInfoDisplay)));
+            q->m_curPid = scanWindowPid(getSubwindow(DefaultRootWindow(windowInfoDisplay))).first;
             //qCInfo(logWordWizard) << "cursor window name:" << q->m_curApp;
             emit q->mousePress(event->u.keyButtonPointer.rootX, event->u.keyButtonPointer.rootY);
             break;
@@ -289,6 +290,26 @@ QString xEventMonitorPrivate::getWindowName(Window window)
     return windowName;
 }
 
+QString xEventMonitor::getAppByPid(int pid) {
+    if (pid == m_curPid) {
+        return m_curApp;
+    }
+
+    // 通过PID获取进程名
+    QString processName = d->getProcessName(pid);
+    if (!processName.isEmpty()) {
+        return processName;
+    }
+
+    // 尝试通过窗口获取应用名
+    QPair<int, Window> windowInfo = d->getWindowAtCursor();
+    if (windowInfo.first == pid) {
+        return d->getWindowName(windowInfo.second);
+    }
+
+    return QString();
+}
+
 bool xEventMonitor::isWheelEvent(int detail)
 {
     //滚轮判断
