@@ -29,6 +29,8 @@ public:
     xEventMonitor(QObject *parent = 0);
     ~xEventMonitor() override;
     QString getCurApp() override { return m_curApp; }
+    int getCurPid() override { return m_curPid; }
+    QString getAppByPid(int pid) override;
 Q_SIGNALS:
     void mousePress(int x, int y) override;
     void mouseRelease(int x, int y) override;
@@ -42,6 +44,7 @@ private:
     bool isOpenDisplay = false;
     xEventMonitorPrivate *d;
     QString m_curApp;
+    int m_curPid;
 };
 }
 
