@@ -19,6 +19,7 @@
 #include "util.h"
 #include "esystemcontext.h"
 #include <report/followfunctionpoint.h>
+#include <report/knowledgefunctionpoint.h>
 #include <report/eventlogutil.h>
 #include <apputils.h>
 #include <application.h>
@@ -65,10 +66,17 @@ WordWizard::WordWizard(QObject *parent) : QObject(parent)
     m_timer->setInterval(100);
     m_timer->setSingleShot(true);
 
+    m_processCheckTimer = new QTimer(this);
+    m_processCheckTimer->setInterval(3600000); // 每1小时检查一次
+    m_processCheckTimer->setSingleShot(false);
+
     initCunstomFunctions();
     initWordWizard();
     initConnect();
     FcitxInputServer::getInstance();
+
+    connect(m_processCheckTimer, &QTimer::timeout, this, &WordWizard::checkDisabledProcesses);
+    m_processCheckTimer->start();
 }
 
 WordWizard::~WordWizard()
@@ -93,7 +101,8 @@ void WordWizard::initWordWizard()
     bool isHidden = DConfigManager::instance()->value(WORDWIZARD_GROUP, WORDWIZARD_ISHIDDEN).toBool();
     qCInfo(logWordWizard) << "Initial hidden status:" << isHidden;
     m_isHidden = isHidden;
-    m_selectwid->isShowHiddenAction(!isHidden);
+    m_selectwid->isEnabledAction(!isHidden);
+    m_inputWindow->isEnabledAction(!isHidden);
 
     QVariant disabledAppsVar = DConfigManager::instance()->value(WORDWIZARD_GROUP, WORDWIZARD_DISABLED_APPS);
     if (disabledAppsVar.isValid()) {
@@ -136,6 +145,7 @@ void WordWizard::initCunstomFunctions()
             false,
             WIZARD_TYPE_TRANSLATE
         });
+#ifdef ENABLE_ASSISTANT
         kCustomFunctionList.append(CustomFunction {
             "",
             "",
@@ -143,6 +153,7 @@ void WordWizard::initCunstomFunctions()
             false,
             WIZARD_TYPE_KNOWLEDGE
         });
+#endif
         kCustomFunctionList.append(CustomFunction {
             "",
             "",
@@ -186,6 +197,10 @@ void WordWizard::initCunstomFunctions()
         QJsonObject json = jsonDoc.object();
         // 安全检查
         CustomFunction func(json);
+#ifndef ENABLE_ASSISTANT
+        if (func.defaultFunctionType == WIZARD_TYPE_KNOWLEDGE)
+            continue;
+#endif
         if (!func.isCustom) {
             // 默认项安全检查
             if (func.defaultFunctionType < WIZARD_TYPE_SEARCH || func.defaultFunctionType > WIZARD_TYPE_KNOWLEDGE) {
@@ -215,6 +230,11 @@ void WordWizard::initCunstomFunctions()
         if (defaultFunctionTypeSet.contains(i)) {
             continue;
         }
+#ifndef ENABLE_ASSISTANT
+        if (i == WIZARD_TYPE_KNOWLEDGE) {
+            continue;
+        }
+#endif
 
         kCustomFunctionList.append(CustomFunction {
             "",
@@ -249,6 +269,8 @@ void WordWizard::initConnect()
 
     connect(m_selectwid, &WizardWrapper::signalFunctionTriggered, this, &WordWizard::onFunctionTriggered);
     connect(m_selectwid, &WizardWrapper::signalRequestServer, this, &WordWizard::onSaveClipText);
+    connect(m_inputWindow, &InputWindow::signalFunctionTriggered, this, &WordWizard::onFunctionTriggered);
+    connect(m_inputWindow, &InputWindow::signalRequestServer, this, &WordWizard::onSaveClipText);
     connect(m_selectwid, &WizardWrapper::signalCloseBtnClicked, this, &WordWizard::onCloseBtnClicked);
     connect(m_selectwid, &WizardWrapper::signalIconBtnClicked, this, [&]() {
         this->onIconBtnClicked(m_selectclip->getClipText());
@@ -274,6 +296,9 @@ void WordWizard::initConnect()
     connect(m_inputWindow, &InputWindow::signalCloseBtnClicked, this, &WordWizard::onCloseBtnClicked);
 
     connect(m_selectwid, &WizardWrapper::signalDisableInApp, this, &WordWizard::onDisableInApp);
+    connect(m_selectwid, &WizardWrapper::signalDisableInProcess, this, &WordWizard::onDisableInProcess);
+    connect(m_inputWindow, &InputWindow::signalDisableInApp, this, &WordWizard::onDisableInApp);
+    connect(m_inputWindow, &InputWindow::signalDisableInProcess, this, &WordWizard::onDisableInProcess);
     connect(m_selectwid, &WizardWrapper::signalShowInputWindow, this, &WordWizard::onShowInputWindow);
 
     connect(m_eventMonitor, SIGNAL(mousePress(int, int)), this, SLOT(onGlobalMousePress(int, int)), Qt::QueuedConnection);
@@ -321,7 +346,7 @@ void WordWizard::onGlobalMousePress(int x, int y)
     }
 
     geoRect = m_inputWindow->geometry();
-    if (geoRect.contains(m_cursorPos) && m_inputWindow->isVisible()) {
+    if ((geoRect.contains(m_cursorPos) || m_inputWindow->isMouseInside()) && m_inputWindow->isVisible()) {
         return;
     }
 
@@ -411,15 +436,19 @@ void WordWizard::onShowScribeWord()
 {
     // x11环境获取当前app信息
     m_curApp     = dynamic_cast<BaseMonitor *>(m_eventMonitor)->getCurApp();
+    m_curPid     = dynamic_cast<BaseMonitor *>(m_eventMonitor)->getCurPid();
 
     QString selectedText = m_selectclip->getClipText();
-    m_selectwid->setKnowledgeActionEnabled(selectedText.length() >= 10);
     
     // 检查当前应用是否被禁用（快捷键不禁用）
     if (!m_isShortcut && isAppDisabled(m_curApp)) {
         qCInfo(logWordWizard) << "App disabled, not showing WizardWrapper:" << m_curApp;
         return;
     }
+    if (!m_isShortcut && isProcessDisabled(m_curPid, m_curApp)) {
+        qCInfo(logWordWizard) << "Process disabled, not showing WizardWrapper:" << m_curPid <<"("<<m_curApp<<")";
+        return;
+    }
 
 #ifdef COMPILE_ON_V25
     if (ESystemContext::isTreeland()) {
@@ -444,6 +473,7 @@ void WordWizard::onShowScribeWord()
             m_isMousePress = false;
             m_isMouseRelease = false;
         }
+        m_selectwid->setKnowledgeActionEnabled(selectedText.length() >= 10);
         return;
     }
 #endif
@@ -473,6 +503,7 @@ void WordWizard::onShowScribeWord()
         m_isMousePress = false;
         m_isMouseRelease = false;
     }
+    m_selectwid->setKnowledgeActionEnabled(selectedText.length() >= 10);
 }
 
 bool WordWizard::launchUosBrowser(QString url) {
@@ -590,35 +621,8 @@ bool WordWizard::doAddToKnowledgeBase(const QString &text)
 
 void WordWizard::onHiddenActionTriggered()
 {
-    DDialog dialog("",tr("After hidden, the FollowAlong can still be called by pressing Super+R bar, and can also be re-enabled in UOS AI settings."));
-    dialog.setWindowFlags(dialog.windowFlags() | Qt::Tool | Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint);
-    dialog.setFixedWidth(380);
-    dialog.setIcon(QIcon(":assets/images/tips.svg"));
-    dialog.addSpacing(20);
-    DLabel imageLabel;
-    QString iconName = QString(":/icons/deepin/builtin/%1/icons/");
-    if (Util::checkLanguage())
-        iconName += "uos-ai-assistant_intro_128px.svg/normal.svg";
-    else
-        iconName += "uos-ai-assistant_intro_en_128px.svg/normal.svg";
-
-    if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType)
-        iconName = iconName.arg("light");
-    else
-        iconName = iconName.arg("dark");
-    imageLabel.setPixmap(Util::loadSvgPixmap(iconName, QSize(198, 129)));
-    dialog.addContent(&imageLabel, Qt::AlignCenter);
-    dialog.addButton(tr("Cancel", "button"), false, DDialog::ButtonNormal);
-    dialog.addButton(tr("Disable", "button"), true, DDialog::ButtonRecommend);
-    auto labelList = dialog.findChildren<QLabel *>();
-    for (auto messageLabel : labelList) {
-        if ("MessageLabel" == messageLabel->objectName())
-            messageLabel->setFixedWidth(dialog.width() - 20);
-    }
-    if (DDialog::Accepted == dialog.exec()) {
-        onChangeHiddenStatus(false);
-        emit signalHiddenwidget(true);
-    }
+    onChangeHiddenStatus(false);
+    emit signalHiddenwidget(true);
 }
 
 void WordWizard::onChangeXEventMonitorStatus(bool isopen)
@@ -644,6 +648,7 @@ void WordWizard::onFunctionTriggered(int wizardtype, const QPoint &cursorPos, bo
         if (wizardtype == WIZARD_TYPE_HIDDEN) {
             onHiddenActionTriggered();
             m_selectwid->close();
+            m_inputWindow->close();
             m_selectwid->setWidgetVisible(false);
         } else if (wizardtype == WIZARD_TYPE_CUSTOM) {
             QString locateTitle(tr("UOS AI FollowAlong"));
@@ -659,6 +664,7 @@ void WordWizard::onFunctionTriggered(int wizardtype, const QPoint &cursorPos, bo
             m_selectwid->close();
             m_selectwid->setWidgetVisible(false);
             Q_EMIT sigToCloseAiQuick();
+            ReportIns()->writeEvent(report::KnowledgeFunctionPoint("FollowAlong").assemblingData());
             if (doAddToKnowledgeBase(m_selectclip->getClipText())) {
                 // 显示成功Toast
                 m_selectwid->showToast(tr("Added"));
@@ -729,7 +735,8 @@ void WordWizard::onChangeHiddenStatus(bool isShow)
     qCInfo(logWordWizard) << "Changing hidden status to:" << isShow;
     DConfigManager::instance()->setValue(WORDWIZARD_GROUP, WORDWIZARD_ISHIDDEN, !isShow);
     m_isHidden = !isShow;
-    m_selectwid->isShowHiddenAction(isShow);
+    m_selectwid->isEnabledAction(isShow);
+    m_inputWindow->isEnabledAction(isShow);
 }
 
 void WordWizard::onDisableInApp()
@@ -743,9 +750,37 @@ void WordWizard::onDisableInApp()
     m_selectclip->clearClipText();
     emit signalAddDisabledApp(m_curApp);
     m_selectwid->close();
+    m_inputWindow->close();
     m_selectwid->setWidgetVisible(false);
 }
 
+void WordWizard::onDisableInProcess()
+{
+    qCInfo(logWordWizard) << "Disabling in process:" <<m_curPid << "("<<m_curApp<<")";
+    m_disabledProcess[m_curPid] = m_curApp;
+    m_selectclip->clearClipText();
+    m_selectwid->close();
+    m_inputWindow->close();
+    m_selectwid->setWidgetVisible(false);
+}
+
+void WordWizard::checkDisabledProcesses()
+{
+    QMutableMapIterator<int, QString> it(m_disabledProcess);
+    while (it.hasNext()) {
+        it.next();
+        int pid = it.key();
+        QString expectedApp = it.value();
+        
+        // 检查进程是否存在且应用名匹配
+        QString currentApp = dynamic_cast<BaseMonitor *>(m_eventMonitor)->getAppByPid(pid);
+        if (currentApp.isEmpty() || currentApp != expectedApp) {
+            qCInfo(logWordWizard) << "Removing invalid process entry:" << pid << "(" << expectedApp << ")";
+            it.remove();
+        }
+    }
+}
+
 void WordWizard::getScreenRect()
 {
     QList<QScreen *> screens = QGuiApplication::screens();
@@ -788,6 +823,13 @@ bool WordWizard::isAppDisabled(const QString &appName)
     return m_disabledApps.contains(appName);;
 }
 
+bool WordWizard::isProcessDisabled(int pid, const QString &appName)
+{
+    if (ESystemContext::isWayland() || pid == 0 || appName.isEmpty())
+        return false;
+    return m_disabledProcess[pid] == appName;
+}
+
 void WordWizard::updateDisabledApps(const QStringList &appList)
 {
     if (m_disabledApps != appList) {
