@@ -131,6 +131,7 @@ public slots:
     void onFocusIn() { kIsFcitxWritable = true; }
     void onFocusOut() { kIsFcitxWritable = false; }
     void onDisableInApp();
+    void onDisableInProcess();
     void updateDisabledApps(const QStringList &appList);
     void onShowInputWindow(const QPoint &pos, const QRect &screenRect, int wizardWidth, int wizardHeight);
     static void onIconBtnClicked(QString text = "");
@@ -141,6 +142,8 @@ private:
     void getScreenRect();
     void adjustMulScreenPos(QPoint &pos);
     bool isAppDisabled(const QString &appName);
+    bool isProcessDisabled(int pid, const QString &appName);
+    void checkDisabledProcesses();
 
     static volatile bool kIsFcitxWritable;
     volatile bool m_isWebviewOk = true;
@@ -171,9 +174,12 @@ private:
     QRect m_screenRect;
 
     QTimer *m_timer = nullptr;
+    QTimer *m_processCheckTimer = nullptr;
 
     QString m_curApp;
     QStringList m_disabledApps; // 存储禁用的应用列表
+    int m_curPid;
+    QMap<int, QString> m_disabledProcess; // 存储禁用的进程列表
 };
 }
 #endif // WORDWIZARD_H
