@@ -65,6 +65,10 @@ void WizardWrapper::initUI()
     DPlatformWindowHandle handle(this, this);
     handle.setWindowRadius(8);
     this->setObjectName("selectionwidget");
+    this->setBlurEnabled(true);
+    this->setBlurRectXRadius(8);
+    this->setBlurRectYRadius(8);
+    this->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
     installEventFilter(this);
 
     // 创建输入区域容器
@@ -104,15 +108,45 @@ void WizardWrapper::initUI()
     m_closeBtn->setFixedHeight(24);
     m_closeBtn->installEventFilter(this);
 
-    m_disableMenu = new DMenu(tr("Disable"));
-    m_disableInAppAction = new QAction(tr("Disable in This Application"));
-    m_disableGlobalAction = new QAction(tr("Disable Globally"));
+    // Create  menu for disable actions
+    m_disableMenu = new CustomDMenu(this);
+    m_disableInProcessAction = createCustomMenuAction(tr("Hide until restarting this app"), "uos-ai-assistant_hide");
+    m_disableInAppAction = createCustomMenuAction(tr("Disable in This Application"), "uos-ai-assistant_disabled");
+    m_disableGlobalAction = createCustomMenuAction(tr("Disable Globally"), "uos-ai-assistant_disabled");
+    if (ESystemContext::isWayland()){
+        m_disableInProcessAction->setVisible(false);
+        m_disableInAppAction->setVisible(false);
+    }
+    m_disableMenu->addAction(m_disableInProcessAction);
     m_disableMenu->addAction(m_disableInAppAction);
     m_disableMenu->addAction(m_disableGlobalAction);
     m_disableMenu->installEventFilter(this);
-    if (ESystemContext::isWayland())
-        m_disableInAppAction->setVisible(false);
+    m_disableMenu->addSeparator();
     m_customSettings = new QAction(tr("Custom Settings"));
+    
+    // Add clickable "Go to UOS AI Assistant Settings" text
+    m_settingAction = new QWidgetAction(this);
+    // 获取活动色
+    DPalette palette = DGuiApplicationHelper::instance()->applicationPalette();
+    QColor activeColor = palette.color(DPalette::Normal, DPalette::Highlight);
+    QString colorName = activeColor.name(QColor::HexRgb);
+    
+    m_settingLabel = new QLabel(QString(tr("Go to <a href=\"#\" style=\"color:%1;text-decoration:none;\">Settings</a> to re-enable it.")).arg(colorName));
+    m_settingLabel->setTextFormat(Qt::RichText);
+    m_settingLabel->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
+    m_settingLabel->setFixedHeight(34);
+    DFontSizeManager::instance()->bind(m_settingLabel, DFontSizeManager::T9, QFont::Normal);
+
+    QWidget *m_settingWidget = new QWidget(this);
+    QHBoxLayout* settingLayout = new QHBoxLayout(m_settingWidget);
+    settingLayout->setContentsMargins(31, 0, 0, 0);
+    settingLayout->setSpacing(0);
+    settingLayout->addWidget(m_settingLabel);
+    m_settingAction->setDefaultWidget(m_settingWidget);
+    m_disableMenu->addAction(m_settingAction);
+    connect(m_settingLabel, &QLabel::linkActivated, this, [this] {
+        emit signalFunctionTriggered(WordWizard::WIZARD_TYPE_CUSTOM, m_cursorPos + QPoint(this->rect().width() / 2, 0), false);
+    });
 
     m_moreMenu = new CustomDMenu(this);
     m_moreMenu->setMinimumWidth(92);
@@ -136,11 +170,15 @@ void WizardWrapper::initConnect()
     connect(m_iconBtn, &DIconButton::clicked, this, &WizardWrapper::onIconBtnClicked);
     connect(m_inputArea, &InputPlaceholderWidget::clicked, this, &WizardWrapper::onInputAreaClicked);
     connect(m_moreMenu, &QMenu::triggered, this, &WizardWrapper::onMoreMenuTriggered);
+    connect(m_disableMenu, &QMenu::triggered, this, &WizardWrapper::onDisableMenuTriggered);
     connect(m_moreBtn, &WizardDPushButton::clicked, this, &WizardWrapper::showMenu);
 
     //避免随航检测到mouseRelease事件后又弹出
     connect(m_closeBtn, &WizardDPushButton::clicked, this, [&] {
-        QTimer::singleShot(1, this, &WizardWrapper::onCloseWidget);
+        emit signalRequestServer();
+        adjustSize();
+        m_disableMenu->exec(m_closeBtn->mapToGlobal(m_closeBtn->rect().bottomLeft() + QPoint(0, 5)));
+        m_closeBtn->update();
     });
 
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &WizardWrapper::onUpdateSystemTheme);
@@ -170,6 +208,17 @@ bool WizardWrapper::eventFilter(QObject *watched, QEvent *event)
         m_mouseInside = false;
     }
 
+    // 处理自定义菜单项的hover事件
+    if (m_customMenuWidgets.contains(static_cast<QWidget*>(watched))) {
+        if (event->type() == QEvent::HoverEnter) {
+            updateHoverStyle(static_cast<QWidget*>(watched), true);
+            return true;
+        } else if (event->type() == QEvent::HoverLeave) {
+            updateHoverStyle(static_cast<QWidget*>(watched), false);
+            return true;
+        }
+    }
+
     // 拖动逻辑
     bool isDraggableWidget = false;
     if (!ESystemContext::isTreeland() && m_isExtend) {
@@ -264,7 +313,6 @@ void WizardWrapper::leaveEvent(QEvent *event)
 void WizardWrapper::onUpdateSystemTheme(const DGuiApplicationHelper::ColorType &themeType)
 {
     DPalette parentPb = DGuiApplicationHelper::instance()->applicationPalette();
-    QColor backgroundColor = parentPb.color(DPalette::Normal, DPalette::NColorTypes);
     if (themeType == DGuiApplicationHelper::LightType) {
         if(m_lineSep) {
             DPalette sepPalette = m_lineSep->palette();
@@ -273,6 +321,7 @@ void WizardWrapper::onUpdateSystemTheme(const DGuiApplicationHelper::ColorType &
             m_lineSep1->setPalette(sepPalette);
             m_lineSep2->setPalette(sepPalette);
         }
+        QColor backgroundColor = parentPb.color(DPalette::Normal, DPalette::NColorTypes);
         setMaskColor(backgroundColor);
         setMaskAlpha(255);
     } else {
@@ -283,9 +332,26 @@ void WizardWrapper::onUpdateSystemTheme(const DGuiApplicationHelper::ColorType &
             m_lineSep1->setPalette(sepPalette);
             m_lineSep2->setPalette(sepPalette);
         }
+        QColor backgroundColor(32, 32, 32);
         setMaskColor(backgroundColor);
-        setMaskAlpha(204);
+        setMaskAlpha(0.8 * 255);
     }
+    // Update setting label link color to use active palette color
+    if (m_settingLabel) {
+        DPalette palette = DGuiApplicationHelper::instance()->applicationPalette();
+        QColor activeColor = palette.color(DPalette::Normal, DPalette::Highlight);
+        QString colorName = activeColor.name(QColor::HexRgb);
+        m_settingLabel->setText(QString(tr("Go to <a href=\"#\" style=\"color:%1;text-decoration:none;\">Settings</a> to re-enable it.")).arg(colorName));
+    }
+
+    for (QWidget* widget : m_customMenuWidgets) {
+        if (widget) {
+            // 检查widget是否处于hover状态
+            bool isHovered = widget->underMouse();
+            updateHoverStyle(widget, isHovered);
+        }
+    }
+
     update();
 }
 
@@ -369,15 +435,7 @@ void WizardWrapper::onMoreMenuTriggered(const QAction *action)
     int wizardtype = -1;
     bool isCustom = false;
 
-    if (action == m_disableGlobalAction) {
-        qCDebug(logWordWizard) << "Disable globally action triggered";
-        wizardtype = WordWizard::WIZARD_TYPE_HIDDEN;
-        isCustom = false;
-    } else if (!ESystemContext::isWayland() && action == m_disableInAppAction) {
-        qCDebug(logWordWizard) << "Disable in app action triggered";
-        emit signalDisableInApp();
-        return;
-    } else if (action == m_customSettings) {
+    if (action == m_customSettings) {
         qCDebug(logWordWizard) << "Custom settings action triggered";
         wizardtype = WordWizard::WIZARD_TYPE_CUSTOM;
         isCustom = false;
@@ -410,6 +468,36 @@ void WizardWrapper::onMoreMenuTriggered(const QAction *action)
     emit signalFunctionTriggered(wizardtype, m_cursorPos + QPoint(this->rect().width() / 2, 0), isCustom);
 }
 
+void WizardWrapper::onDisableMenuTriggered(const QAction *action)
+{
+    if (!WelcomeDialog::isAgreed()) {
+        qCWarning(logWordWizard) << "Welcome dialog not agreed, closing wizard";
+        this->close();
+        m_isVisible = false;
+        WelcomeDialog::instance(false)->exec();
+        return;
+    }
+
+    int wizardtype = -1;
+    bool isCustom = false;
+
+    if (action == m_disableGlobalAction) {
+        qCDebug(logWordWizard) << "Disable globally action triggered";
+        wizardtype = WordWizard::WIZARD_TYPE_HIDDEN;
+        isCustom = false;
+    } else if (!ESystemContext::isWayland() && action == m_disableInAppAction) {
+        qCDebug(logWordWizard) << "Disable in app action triggered";
+        emit signalDisableInApp();
+        return;
+    } else if (!ESystemContext::isWayland() && action == m_disableInProcessAction) {
+        qCDebug(logWordWizard) << "Disable in process action triggered";
+        emit signalDisableInProcess();
+        return;
+    }
+
+    emit signalFunctionTriggered(wizardtype, m_cursorPos + QPoint(this->rect().width() / 2, 0), isCustom);
+}
+
 void WizardWrapper::onButtonClicked()
 {
     int wizardtype = -1;
@@ -463,20 +551,10 @@ void WizardWrapper::showMenu()
 
 void WizardWrapper::onCloseWidget()
 {
+    // Keep this as fallback if needed elsewhere
     qCDebug(logWordWizard) << "Closing widget";
     this->close();
     m_isVisible = false;
-    if (isFirstClose()) {
-        qCInfo(logWordWizard) << "First time close, showing tips dialog";
-        DDialog dialog("",tr("After selecting the text, press the Super+R bar can also wake up the UOS AI FollowAlong."));
-        // 设置成与aiquickdialog同层级，防止aiquickdialog覆盖closedialog导致伪卡死
-        dialog.setWindowFlags(dialog.windowFlags() | Qt::Tool | Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint);
-        dialog.setMinimumWidth(380);
-        dialog.setIcon(QIcon(":assets/images/tips.svg"));
-        dialog.addButton(tr("Ok", "button"), true, DDialog::ButtonNormal);
-        dialog.exec();
-        DConfigManager::instance()->setValue(WORDWIZARD_GROUP, WORDWIZARD_ISFIRSTCLOSE, false);
-    }
     emit signalCloseBtnClicked();
 }
 
@@ -527,12 +605,13 @@ void WizardWrapper::adjustShowPos(const QRect &screenRect, QPoint &pos)
         pos.setY(widgetRect.top() - 2 * widgetRect.height());
 }
 
-void WizardWrapper::isShowHiddenAction(bool isShow)
+void WizardWrapper::isEnabledAction(bool isEnabled)
 {
-    m_disableMenuAction->setVisible(isShow);
-    if (!ESystemContext::isWayland())
-        m_disableInAppAction->setVisible(isShow);
-    m_disableGlobalAction->setVisible(isShow);
+    if (!ESystemContext::isWayland()) {
+        m_disableInAppAction->setEnabled(isEnabled);
+        m_disableInProcessAction->setEnabled(isEnabled);
+    }
+    m_disableGlobalAction->setEnabled(isEnabled);
 }
 
 bool WizardWrapper::isFirstClose()
@@ -813,9 +892,6 @@ void WizardWrapper::updateButtonsFromCustomFunctions()
     }
     m_customActions.clear();
 
-    if (m_disableMenuAction) {
-        m_moreMenu->removeAction(m_disableMenuAction);
-    }
     m_moreMenu->removeAction(m_customSettings);
     QList<QAction*> actions = m_moreMenu->actions();
     for (QAction* action : actions) {
@@ -864,7 +940,6 @@ void WizardWrapper::updateButtonsFromCustomFunctions()
         m_moreMenu->addSeparator();
     }
     m_moreMenu->addAction(m_customSettings);
-    m_disableMenuAction = m_moreMenu->addMenu(m_disableMenu);
 }
 
 void WizardWrapper::updateCustomFunctions()
@@ -1003,7 +1078,6 @@ void WizardWrapper::showToast(const QString &message)
     if (!screen) {
         screen = QGuiApplication::primaryScreen();
     }
-    
     QRect screenGeometry = screen->geometry();
     
     // 计算Toast位置 - 显示在屏幕正下方中央
@@ -1019,4 +1093,87 @@ void WizardWrapper::showToast(const QString &message)
     floatMessage->show();
 }
 
+QAction* WizardWrapper::createCustomMenuAction(const QString& text, const QString& iconName)
+{
+    QWidgetAction* action = new QWidgetAction(this);
 
+    // Create a custom widget for the menu item
+    QWidget* widget = new QWidget();
+    widget->setFixedHeight(34);
+    widget->setObjectName("customMenuWidget");
+    QHBoxLayout* layout = new QHBoxLayout(widget);
+    layout->setContentsMargins(10, 6, 65, 6);
+    layout->setSpacing(6);
+
+    // Create icon label
+    QLabel* iconLabel = new QLabel();
+    iconLabel->setPixmap(QIcon::fromTheme(iconName).pixmap(16, 16));
+    iconLabel->setFixedSize(16, 16);
+    iconLabel->setObjectName("customMenuIcon");
+
+    // Create text label
+    QLabel* textLabel = new QLabel(text);
+    textLabel->setObjectName("customMenuText");
+    DFontSizeManager::instance()->bind(textLabel, DFontSizeManager::T6, QFont::Normal);
+
+    layout->addWidget(iconLabel);
+    layout->addWidget(textLabel);
+    layout->addStretch();
+
+    widget->setLayout(layout);
+    
+    // Enable mouse tracking for hover effects
+    widget->setMouseTracking(true);
+    widget->setAttribute(Qt::WA_Hover, true);
+    
+    // Install event filter to handle hover events
+    widget->installEventFilter(this);
+    
+    // Store widget reference for hover handling
+    m_customMenuWidgets.append(widget);
+    m_customMenuWidgetIconNames.append(iconName);
+    action->setDefaultWidget(widget);
+
+    return action;
+}
+
+void WizardWrapper::updateHoverStyle(QWidget* widget, bool hovered)
+{
+    if (!widget) return;
+
+    QString iconName = m_customMenuWidgetIconNames.value(m_customMenuWidgets.indexOf(widget));
+    
+    // Find the icon label within the widget
+    QLabel* iconLabel = widget->findChild<QLabel*>("customMenuIcon");
+    if (!iconLabel) return;
+    
+    if (hovered) {
+        // Get current system palette colors
+        DPalette palette = DGuiApplicationHelper::instance()->applicationPalette();
+        QColor highlightColor = palette.color(DPalette::Normal, DPalette::Highlight);
+        QColor highlightTextColor = palette.color(DPalette::Normal, DPalette::HighlightedText);
+        
+        QString hoverStyle = QString(
+                    "#customMenuWidget {"
+                    "    background-color: %1;"
+                    "}"
+                    "#customMenuWidget #customMenuText {"
+                    "    color: %2;"
+                    "}"
+                    ).arg(
+                    highlightColor.name(),
+                    highlightTextColor.name()
+                    );
+        
+        widget->setStyleSheet(hoverStyle);
+        iconLabel->setPixmap(QIcon::fromTheme(iconName).pixmap(16, 16, QIcon::Mode::Selected));
+    } else {
+        // Reset to default style
+        widget->setStyleSheet("");
+        if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
+            iconLabel->setPixmap(QIcon::fromTheme(iconName).pixmap(16, 16));
+        } else {
+            iconLabel->setPixmap(QIcon::fromTheme(iconName).pixmap(16, 16, QIcon::Mode::Selected));
+        }
+    }
+}
