@@ -14,6 +14,8 @@
 #include <QPropertyAnimation>
 #include <QToolTip>
 #include <QMouseEvent>
+#include <QWidgetAction>
+#include <QLabel>
 
 DGUI_USE_NAMESPACE
 
@@ -57,7 +59,7 @@ public:
     static WizardWrapper &instance();
     void initAnimation();
     void showWizardWrapperWithAnimation();
-    void isShowHiddenAction(bool isShow);
+    void isEnabledAction(bool isEnabled);
     void updateCustomFunctions();
     bool isMouseInside() { return m_mouseInside; }
     bool isWidgetVisible() { return m_isVisible; }
@@ -87,11 +89,13 @@ signals:
     void signalIconBtnClicked();
     void signalEscEvent();
     void signalDisableInApp();
+    void signalDisableInProcess();
     void signalShowInputWindow(const QPoint &pos, const QRect &screenRect, int wizardWidth, int wizardHeight);
 
 public slots:
     void showScribeWordsAtCursorPosition(QRect screenRect, QPoint& point, bool isMouseRelease, bool isShortcut);
     void onMoreMenuTriggered(const QAction *action);
+    void onDisableMenuTriggered(const QAction *action);
     void onButtonClicked();
     void showMenu();
     void onCloseWidget();
@@ -112,6 +116,8 @@ private:
     void checkAndUpdateLayout();
     int calculateWidth();
     void clearLayout();
+    QAction* createCustomMenuAction(const QString& text, const QString& iconName);
+    void updateHoverStyle(QWidget* widget, bool hovered);
     Q_DISABLE_COPY(WizardWrapper)
 
     DTK_WIDGET_NAMESPACE::DIconButton *m_iconBtn = nullptr;
@@ -121,14 +127,16 @@ private:
     WizardDPushButton *m_closeBtn = nullptr;
 
     CustomDMenu *m_moreMenu = nullptr;
+    CustomDMenu *m_disableMenu = nullptr;
     DTK_WIDGET_NAMESPACE::DWidget *m_lineSep = nullptr;
     DTK_WIDGET_NAMESPACE::DWidget *m_lineSep1 = nullptr;
     DTK_WIDGET_NAMESPACE::DWidget *m_lineSep2 = nullptr;
-    DTK_WIDGET_NAMESPACE::DMenu *m_disableMenu = nullptr;
+    QAction *m_disableInProcessAction = nullptr;
     QAction *m_disableInAppAction = nullptr;
     QAction *m_disableGlobalAction = nullptr;
-    QAction *m_disableMenuAction = nullptr;
     QAction *m_customSettings = nullptr;
+    QWidgetAction *m_settingAction = nullptr;
+    QLabel *m_settingLabel = nullptr;
 
     QList<QAction *> m_customActions;
 
@@ -145,6 +153,9 @@ private:
     QPoint m_dragStartPos;
 
     uint m_customFunctionListHash = 0;
+    
+    QList<QWidget*> m_customMenuWidgets;
+    QList<QString> m_customMenuWidgetIconNames;
 };
 }
 #endif // WIZARDWRAPPER_H
