@@ -41,6 +41,8 @@ enum ExtFileType {
 inline constexpr char kExtFile[] = "files";
 inline constexpr char kExtFileType[] = "type";
 inline constexpr char kExtFileContent[] = "content";
+inline constexpr char kExtFileMetaInfo[] = "metaInfo";
+inline constexpr char kExtFileMetaInfoDocPath[] = "docPath";
 
 struct ChatChunk
 {
