@@ -12,18 +12,32 @@
 
 #include <QJsonArray>
 #include <QLoggingCategory>
+#include <QThread>
 
 using namespace uos_ai;
 
 Q_DECLARE_LOGGING_CATEGORY(logWrapper)
 
+// 单例模式实现
+LLMServiceVendor *LLMServiceVendor::instance()
+{
+    static LLMServiceVendor ins;
+    return &ins;
+}
+
 LLMServiceVendor::LLMServiceVendor(QObject *parent) : QObject(parent)
 {
-
+    Q_ASSERT(QThread::currentThread() == qApp->thread());
 }
 
 void LLMServiceVendor::initExternal()
 {
+    QMutexLocker locker(&m_mutex);
+    if (inited)
+        return;
+
+    inited = true;
+
     extServer.clear();
 #ifdef ENABLE_MODEL_PLUGIN
     initModelPlugin();
@@ -81,6 +95,7 @@ void LLMServiceVendor::initAgent()
 
 void LLMServiceVendor::updateAgent()
 {
+    QMutexLocker locker(&m_mutex);
     QSet<QString> oldList;
     for (QSharedPointer<ExternalAgent> ptr : agentLoader.agents()) {
         for (const LLMServerProxy &m : ptr->getModels())
@@ -111,11 +126,13 @@ void LLMServiceVendor::updateAgent()
         extPlugins.remove(id);
     }
 
+    locker.unlock();
     emit agentChanged();
 }
 
 LLMServerProxy LLMServiceVendor::checkUpdateLLmAccount(const QString &llmId)
 {
+    QMutexLocker locker(&m_mutex);
     LLMServerProxy tmpLLMAccount;
     const QList<LLMServerProxy> &accountList = DbWrapper::localDbWrapper().queryLlmList();
 
@@ -153,8 +170,9 @@ LLMServerProxy LLMServiceVendor::checkUpdateLLmAccount(const QString &llmId)
 
 LLMServerProxy LLMServiceVendor::queryValidServerAccount(const QString &llmId)
 {
+    QMutexLocker locker(&m_mutex);
     const QList<LLMServerProxy> &accountLst = DbWrapper::localDbWrapper().queryLlmList();
-    LLMServerProxy tmpLLMAccount;
+    LLMServerProxy tmpLLMAccount{};
     if (!accountLst.isEmpty()) {
         const auto it = std::find_if(accountLst.begin(), accountLst.end(), [llmId](const LLMServerProxy & account) {
             return account.id == llmId;
@@ -182,6 +200,7 @@ LLMServerProxy LLMServiceVendor::queryValidServerAccount(const QString &llmId)
 
 QList<LLMServerProxy> LLMServiceVendor::queryServerAccountByRole(const AssistantProxy &role)
 {
+    QMutexLocker locker(&m_mutex);
     QList<LLMServerProxy> accountLst;
 
     if (role.type < PLUGIN_ASSISTANT) {
@@ -207,6 +226,7 @@ QList<LLMServerProxy> LLMServiceVendor::queryServerAccountByRole(const Assistant
 
 LLMServerProxy LLMServiceVendor::setCurrentLLMAccountId(const QString &id, const QString &app)
 {
+    QMutexLocker locker(&m_mutex);
     LLMServerProxy account;
     if (extServer.contains(id)) {
         account = extServer.value(id);
@@ -233,6 +253,7 @@ LLMServerProxy LLMServiceVendor::setCurrentLLMAccountId(const QString &id, const
 
 QString LLMServiceVendor::queryLLMAccountList(const QList<LLMChatModel> &excludes)
 {
+    QMutexLocker locker(&m_mutex);
     QJsonArray llmAccountArray;
     for (const LLMServerProxy &account : DbWrapper::localDbWrapper().queryLlmList()) {
         if (excludes.contains(account.model))
@@ -292,6 +313,8 @@ QString LLMServiceVendor::queryLLMAccountListByRole(const AssistantProxy &role,
 {
     QJsonArray llmAccountArray;
     QList<LLMServerProxy> llmAccountLst = queryServerAccountByRole(role);
+
+    QMutexLocker locker(&m_mutex);
     for (const LLMServerProxy &account : llmAccountLst) {
         if (excludes.contains(account.model))
             continue;
@@ -327,11 +350,13 @@ QString LLMServiceVendor::queryLLMAccountListByRole(const AssistantProxy &role,
 
 QString LLMServiceVendor::queryCurLlmIdByAppId(const QString &appid)
 {
+    QMutexLocker locker(&m_mutex);
     return DbWrapper::localDbWrapper().queryCurLlmIdByAppId(appid);
 }
 
 QSharedPointer<LLM> LLMServiceVendor::getCopilot(const LLMServerProxy &serverproxy)
 {       
+    QMutexLocker locker(&m_mutex);
     if (extPlugins.contains(serverproxy.id)) {
         QSharedPointer<LLMPlugin> plugin = extPlugins.value(serverproxy.id);
         Q_ASSERT(plugin);
@@ -358,6 +383,7 @@ QSharedPointer<LLM> LLMServiceVendor::getCopilot(const LLMServerProxy &serverpro
 
 QList<AssistantProxy> LLMServiceVendor::queryAssistantList()
 {
+    QMutexLocker locker(&m_mutex);
     QList<AssistantProxy> assistantList;
 
     for (const LLMServerProxy &account : extServer.values()) {
@@ -393,6 +419,7 @@ QList<AssistantProxy> LLMServiceVendor::queryAssistantList()
 
 AssistantProxy LLMServiceVendor::queryAssistantById(const QString &assistantId)
 {
+    QMutexLocker locker(&m_mutex);
     AssistantProxy assistant;
 
     for (const LLMServerProxy &account : extServer.values()) {
@@ -420,6 +447,7 @@ AssistantProxy LLMServiceVendor::queryAssistantById(const QString &assistantId)
 
 QString LLMServiceVendor::queryIconById(const QString &assistantId, const QString &modelId)
 {
+    QMutexLocker locker(&m_mutex);
     QString iconPath;
     for (const LLMServerProxy &account : extServer.values()) {
         auto plugin = extPlugins.value(account.id);
@@ -438,6 +466,7 @@ QString LLMServiceVendor::queryIconById(const QString &assistantId, const QStrin
 
 QString LLMServiceVendor::queryDisplayNameById(const QString &assistantId)
 {
+    QMutexLocker locker(&m_mutex);
     QString displayName;
     for (const LLMServerProxy &account : extServer.values()) {
         auto plugin = extPlugins.value(account.id);
@@ -456,6 +485,7 @@ QString LLMServiceVendor::queryDisplayNameById(const QString &assistantId)
 
 QVariant LLMServiceVendor::getFAQ(const QString &assistantId)
 {
+    QMutexLocker locker(&m_mutex);
     for (const LLMServerProxy &account : extServer.values()) {
         auto plugin = extPlugins.value(account.id);
         Q_ASSERT(plugin);
