@@ -28,9 +28,9 @@ void Session::cancelRequestTask(const QString &id)
 
 void Session::updateLLMAccount()
 {
-    auto llm  = m_private->m_llmVendor.queryValidServerAccount(m_private->m_appServerProxy.id);
+    auto llm  = LLMVendor()->queryValidServerAccount(m_private->m_appServerProxy.id);
     if (!llm.isValid()) {
-        auto supLLM = m_private->m_llmVendor.queryServerAccountByRole(m_private->m_assistantProxy);
+        auto supLLM = LLMVendor()->queryServerAccountByRole(m_private->m_assistantProxy);
         if (!supLLM.isEmpty()) {
             llm = supLLM.first();
         } else {
@@ -165,6 +165,18 @@ QString Session::requestGenImage(const QString &llmId, const QString &imageDesc)
     return m_private->genImageRequest(llmAccount, imageDesc);
 }
 
+void Session::claimUsageRequest(const QString &llmId)
+{
+    // 兜底检查，如果有办法不同意协议走到这里，直接abort
+    if (!DbWrapper::localDbWrapper().getAICopilotIsOpen()) {
+        qCCritical(logWrapper) << "AI Copilot agreement not accepted, aborting request";
+        abort();
+    }
+
+    LLMServerProxy llmAccount = m_private->queryValidServerAccount(llmId);
+    m_private->claimUsageRequest(llmAccount);
+}
+
 bool Session::setCurrentLLMAccountId(const QString &id)
 {
     qCDebug(logWrapper) << "Setting current LLM account ID:" << id;
@@ -175,7 +187,7 @@ bool Session::setCurrentLLMAccountId(const QString &id)
     }
 
     {
-        QList<LLMServerProxy> llms = m_private->m_llmVendor.queryServerAccountByRole(m_private->m_assistantProxy);
+        QList<LLMServerProxy> llms = LLMVendor()->queryServerAccountByRole(m_private->m_assistantProxy);
         bool found = false;
         if (!llms.isEmpty()) {
             const auto it = std::find_if(llms.begin(), llms.end(), [id](const LLMServerProxy & account) {
@@ -193,7 +205,7 @@ bool Session::setCurrentLLMAccountId(const QString &id)
         }
     }
 
-    LLMServerProxy account = m_private->m_llmVendor.setCurrentLLMAccountId(id, m_private->m_appId);
+    LLMServerProxy account = LLMVendor()->setCurrentLLMAccountId(id, m_private->m_appId);
     if (!account.isValid()) {
         qCWarning(logWrapper) << "Invalid LLM account:" << id;
         return false;
@@ -224,7 +236,7 @@ bool Session::setUosAiLLMAccountId(const QString &id)
     for (const AssistantProxy &assis : assistantLst) {
         if (assis.type == AssistantType::UOS_AI) {
             {
-                QList<LLMServerProxy> llms = m_private->m_llmVendor.queryServerAccountByRole(assis);
+                QList<LLMServerProxy> llms = LLMVendor()->queryServerAccountByRole(assis);
                 bool found = false;
                 if (!llms.isEmpty()) {
                     const auto it = std::find_if(llms.begin(), llms.end(), [id](const LLMServerProxy & account) {
@@ -241,7 +253,7 @@ bool Session::setUosAiLLMAccountId(const QString &id)
                 }
             }
 
-            LLMServerProxy account = m_private->m_llmVendor.setCurrentLLMAccountId(id, assis.id);
+            LLMServerProxy account = LLMVendor()->setCurrentLLMAccountId(id, assis.id);
             if (!account.isValid()) {
                 qCWarning(logWrapper) << "Invalid UOS AI LLM account:" << id;
                 return false;
@@ -300,7 +312,7 @@ bool Session::setCurrentAssistantId(const QString &id)
     AssistantProxy assistant = DbWrapper::localDbWrapper().queryAssistantByid(id);
     if (!assistant.isValid()) {
         qCDebug(logWrapper) << "Assistant not found in local DB, querying from vendor";
-        assistant = m_private->m_llmVendor.queryAssistantById(id);
+        assistant = LLMVendor()->queryAssistantById(id);
         if (!assistant.isValid()) {
             qCWarning(logWrapper) << "Invalid assistant ID:" << id;
             return false;
@@ -321,7 +333,7 @@ bool Session::setCurrentAssistantId(const QString &id)
 
     if (!setCurrentLLMAccountId(llmId)) {
         qCDebug(logWrapper) << "Failed to set LLM account, trying first available LLM";
-        auto supLLM = m_private->m_llmVendor.queryServerAccountByRole(m_private->m_assistantProxy);
+        auto supLLM = LLMVendor()->queryServerAccountByRole(m_private->m_assistantProxy);
         if (!supLLM.isEmpty()) {
             setCurrentLLMAccountId(supLLM.first().id);
         } else {
@@ -396,14 +408,14 @@ QString Session::currentAssistantInstList()
 QString Session::queryLLMAccountList(const QList<LLMChatModel> &excludes)
 {
     qCDebug(logWrapper) << "Querying LLM account list with" << excludes.size() << "excluded models";
-    return m_private->m_llmVendor.queryLLMAccountList(excludes);
+    return LLMVendor()->queryLLMAccountList(excludes);
 }
 
 QString Session::queryLLMAccountListWithRole(const QList<LLMChatModel> &excludes)
 {
     qCDebug(logWrapper) << "Querying LLM account list for role:" << m_private->m_assistantProxy.id 
                        << "with" << excludes.size() << "excluded models";
-    return m_private->m_llmVendor.queryLLMAccountListByRole(m_private->m_assistantProxy, excludes);
+    return LLMVendor()->queryLLMAccountListByRole(m_private->m_assistantProxy, excludes);
 }
 
 QString Session::queryUosAiLLMAccountList() {
@@ -411,7 +423,7 @@ QString Session::queryUosAiLLMAccountList() {
     QList<AssistantProxy> assistantLst = DbWrapper::localDbWrapper().queryAssistantList();
     for (const AssistantProxy &assis : assistantLst) {
         if (assis.type == AssistantType::UOS_AI) {
-            return m_private->m_llmVendor.queryLLMAccountListByRole(assis, QList<LLMChatModel>());
+            return LLMVendor()->queryLLMAccountListByRole(assis, QList<LLMChatModel>());
         }
     }
 
@@ -424,7 +436,7 @@ QString Session::queryAssistantList()
     // 固定角色
     QList<AssistantProxy> assistantLst = DbWrapper::localDbWrapper().queryAssistantList();
     // 插件助手角色
-    assistantLst << m_private->m_llmVendor.queryAssistantList();
+    assistantLst << LLMVendor()->queryAssistantList();
 
     for (const AssistantProxy &assistant : assistantLst) {
         QJsonObject assistantObj;
@@ -476,13 +488,13 @@ AssistantType Session::queryAssistantTypeById(const QString &id)
 QString Session::queryIconById(const QString &assistantId, const QString &modelId)
 {
     qCDebug(logWrapper) << "Querying icon for assistant:" << assistantId << "model:" << modelId;
-    return m_private->m_llmVendor.queryIconById(assistantId, modelId);
+    return LLMVendor()->queryIconById(assistantId, modelId);
 }
 
 QString Session::queryDisplayNameById(const QString &assistantId)
 {
     qCDebug(logWrapper) << "Querying display name for assistant:" << assistantId;
-    return m_private->m_llmVendor.queryDisplayNameById(assistantId);
+    return LLMVendor()->queryDisplayNameById(assistantId);
 }
 
 void Session::launchLLMUiPage(bool showAddllmPage, bool onlyUseAgreement, bool isFromAiQuick, const QString &locateTitle)
@@ -493,6 +505,11 @@ void Session::launchLLMUiPage(bool showAddllmPage, bool onlyUseAgreement, bool i
     emit ServerWrapper::instance()->sigToLaunchMgmt(showAddllmPage, onlyUseAgreement, isFromAiQuick, locateTitle);
 }
 
+void Session::launchGetFreeAccountDlg()
+{
+    emit ServerWrapper::instance()->sigToLaunchGetFreeAccountDlg();
+}
+
 void Session::launchKnowledgeBaseUiPage(const QString &locateTitle)
 {
     qCDebug(logWrapper) << "Launching knowledge base UI page";
