@@ -52,6 +52,9 @@ public Q_SLOTS:
     QString chatRequest(const QString &llmId, const QString &ctx, const QVariantHash &params = {});
     QString searchRequest(const QString &llmId, const QString &ctx);
     QString requestGenImage(const QString &llmId, const QString &imageDesc);
+
+    void claimUsageRequest(const QString &llmId);
+
     /**
      * @brief Set the current model ID.
      * @param id: LLM model ID
@@ -95,6 +98,7 @@ public Q_SLOTS:
      * @brief Launch LLM UI page.
      */
     void launchLLMUiPage(bool showAddllmPage, bool onlyUseAgreement = false, bool isFromAiQuick = false, const QString &locateTitle = "");
+    void launchGetFreeAccountDlg();
 
     void launchKnowledgeBaseUiPage(const QString & locateTitle = "");
 
@@ -150,6 +154,9 @@ signals:
 
     void previewReference(const QString &reference);
 
+    void sigClaimAccountUsageFinished(bool ret, const QString &msg);
+    void sigClaimAgain(bool claimAgain);
+
 private:
     QScopedPointer<SessionPrivate> m_private;
     QString m_uosaiTopAccountId;
