@@ -18,6 +18,8 @@
 #include "agentfactory.h"
 #include "embeddingserver.h"
 #include "global.h"
+#include "global_define.h"
+#include "mcpconfigsyncer.h"
 
 #include <QtConcurrent>
 #include <QImage>
@@ -32,7 +34,7 @@ SessionPrivate::SessionPrivate(Session *session, const QString &appId)
     , m_q(session)
 {
     
-    m_llmVendor.initExternal();
+    LLMVendor()->initExternal();
 
     {
         QString assistantId = DbWrapper::localDbWrapper().queryCurAssistantIdByAppId(appId);
@@ -41,7 +43,7 @@ SessionPrivate::SessionPrivate(Session *session, const QString &appId)
 
     {
         QString llmId = DbWrapper::localDbWrapper().queryLlmIdByAssistantId(m_assistantProxy.id);
-        auto supLLM = m_llmVendor.queryServerAccountByRole(m_assistantProxy);
+        auto supLLM = LLMVendor()->queryServerAccountByRole(m_assistantProxy);
 
         if (llmId.isEmpty() && m_assistantProxy.type == UOS_AI) {
             qCDebug(logWrapper) << "No LLM ID found for UOS AI assistant, trying app's configured model";
@@ -60,7 +62,7 @@ SessionPrivate::SessionPrivate(Session *session, const QString &appId)
             }
         }
 
-        m_appServerProxy = m_llmVendor.queryValidServerAccount(llmId);
+        m_appServerProxy = LLMVendor()->queryValidServerAccount(llmId);
         if (!m_appServerProxy.isValid()) {
             if (!supLLM.isEmpty()) {
                 qCDebug(logWrapper) << "Using first available LLM for assistant";
@@ -87,7 +89,7 @@ SessionPrivate::SessionPrivate(Session *session, const QString &appId)
         m_needQueryFunctions = true;
     });
 
-    connect(&m_llmVendor, &LLMServiceVendor::agentChanged, m_q, &Session::assistantListChanged);
+    connect(LLMVendor(), &LLMServiceVendor::agentChanged, m_q, &Session::assistantListChanged);
 }
 
 SessionPrivate::~SessionPrivate()
@@ -210,7 +212,7 @@ bool SessionPrivate::handleAiServerRequest(QSharedPointer<LLM> copilot, const QS
 
 LLMServerProxy SessionPrivate::queryValidServerAccount(const QString &llmId)
 {
-    LLMServerProxy tmpLLMAccount = m_llmVendor.queryValidServerAccount(llmId);
+    LLMServerProxy tmpLLMAccount = LLMVendor()->queryValidServerAccount(llmId);
     if (!tmpLLMAccount.isValid())
         tmpLLMAccount = m_appServerProxy;
 
@@ -226,7 +228,8 @@ bool SessionPrivate::checkLLMAccountStatus(const QString &uuid, LLMServerProxy &
     if (llmAccount.type == ModelType::FREE_NORMAL || llmAccount.type == ModelType::FREE_KOL) {
         int available = 0;
         QString modelUrl;
-        int errorCode = UosFreeAccounts::instance().getDeterAccountLegal(llmAccount.account.apiKey, available, modelUrl);
+        bool claimAgain = true;
+        int errorCode = UosFreeAccounts::instance().getDeterAccountLegal(llmAccount.account.apiKey, available, modelUrl, claimAgain);
         if (!modelUrl.isEmpty() && llmAccount.model != WXQF_ERNIE_Bot_4)
             // 兼容旧版本添加的KOL bot_4账号
             llmAccount.url = modelUrl;
@@ -259,6 +262,11 @@ bool SessionPrivate::checkLLMAccountStatus(const QString &uuid, LLMServerProxy &
             qCDebug(logWrapper) << "Free account chat usage limit";
             errorType = AIServer::FREEACCOUNTCHATUSAGELIMIT;
             serverCodeTranslation(errorType);
+
+            // 发送可以获取额外额度
+            if (!claimAgain)
+                QMetaObject::invokeMethod(m_q, "sigClaimAgain", Qt::QueuedConnection, Q_ARG(bool, claimAgain));
+
             return false;
         case 6:
             qCDebug(logWrapper) << "Free account text2image usage limit";
@@ -319,7 +327,7 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestChatFunctionText(
         // 免费账号需要解密
         LLMServerProxy tmpLLMAccountDecrypt = tmpLLMAccountLocal.decryptAccount();
 
-        QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(tmpLLMAccountDecrypt);
+        QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(tmpLLMAccountDecrypt);
         if (copilot.isNull()) {
             qCWarning(logWrapper) << "Failed to get copilot instance - uuid:" << uuid;
             eventloop.quit();
@@ -499,7 +507,7 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestRag(LLMServerProx
         // 免费账号需要解密
         LLMServerProxy tmpLLMAccountDecrypt = tmpLLMAccountLocal.decryptAccount();
 
-        QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(tmpLLMAccountDecrypt);
+        QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(tmpLLMAccountDecrypt);
         if (copilot.isNull()) {
             qCWarning(logWrapper) << "Failed to get copilot instance - uuid:" << uuid;
             eventloop.quit();
@@ -613,7 +621,7 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestInstFunction(LLMS
         // 免费账号需要解密
         LLMServerProxy tmpLLMAccountDecrypt = tmpLLMAccountLocal.decryptAccount();
 
-        QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(tmpLLMAccountDecrypt);
+        QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(tmpLLMAccountDecrypt);
         if (copilot.isNull()) {
             qCWarning(logWrapper) << "Failed to get copilot instance - uuid:" << uuid;
             eventloop.quit();
@@ -748,7 +756,7 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestPlugin(LLMServerP
     bool isLoopQuit = false;
 
     QFuture<QString> future = QtConcurrent::run(LLMThreadTaskMana::instance()->threadPool(tmpLLMAccount.id), [=, &eventloop, &isLoopQuit]() {
-        QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(tmpLLMAccount);
+        QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(tmpLLMAccount);
         if (copilot.isNull()) {
             eventloop.quit();
             isLoopQuit = true;
@@ -859,7 +867,7 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestAgent(LLMServerPr
         // 免费账号需要解密
         LLMServerProxy tmpLLMAccountDecrypt = tmpLLMAccountLocal.decryptAccount();
 
-        QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(tmpLLMAccountDecrypt);
+        QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(tmpLLMAccountDecrypt);
         if (copilot.isNull()) {
             eventloop.quit();
             isLoopQuit = true;
@@ -872,12 +880,14 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestAgent(LLMServerPr
             return uuid;
         }
 
-        QSharedPointer<AgentRequestHandler> agent = AgentFactory::instance()->getAgent("default-agent");
+        QSharedPointer<LlmAgent> agent = AgentFactory::instance()->getAgent(kDefaultAgentName);
         copilot->loadParams(params);
         copilot->setCreatedId(uuid);
+        // must be stream
+        copilot->switchStream(true);
 
         connect(m_q, &Session::executionAborted, copilot.data(), &LLM::aborted);
-        connect(copilot.data(), &LLM::aborted, agent.data(), &AgentRequestHandler::cancel);
+        connect(copilot.data(), &LLM::aborted, agent.data(), &LlmAgent::cancel);
 
         m_runTaskIds << uuid;
         LLMThreadTaskMana::instance()->addRequestTask(uuid, copilot.toWeakRef());
@@ -886,7 +896,7 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestAgent(LLMServerPr
 
         // 开启流格式了，才会开启管道
         socketServer.startServer();
-        connect(agent.data(), &AgentRequestHandler::readyReadChatDeltaContent, &socketServer, &AppSocketServer::sendDataToClient);
+        connect(agent.data(), &LlmAgent::readyReadChatDeltaContent, &socketServer, &AppSocketServer::sendDataToClient);
 
         eventloop.quit();
         isLoopQuit = true;
@@ -903,7 +913,7 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestAgent(LLMServerPr
         // 更新llm的账号
         copilot->updateAccount(tmpLLMAccountDecrypt);
 
-        if (!agent->initClient()) {
+        if (!agent->initialize()) {
             TimerEventLoop oneloop;
             oneloop.setTimeout(100);
             oneloop.exec();
@@ -912,12 +922,15 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestAgent(LLMServerPr
             return uuid;
         }
 
+        // 设置模型
+        agent->setModel(copilot);
+        
         QJsonObject response;
         {
             auto ary = QJsonDocument::fromJson(conversation.toUtf8()).array();
             auto question = ary.last();
             ary.pop_back();
-            agent->processRequest(question.toObject(), ary, copilot, params);
+            response = agent->processRequest(question.toObject(), ary, params);
 
             // 如果结束了，只有一种可能，此对象被销毁了，销毁了就不要继续下面的流程了
             if (LLMThreadTaskMana::instance()->isFinished(uuid))
@@ -950,6 +963,9 @@ QPair<AIServer::ErrorType, QStringList> SessionPrivate::requestAgent(LLMServerPr
 
     QFutureWatcher<QString> *futureWatcher = new QFutureWatcher<QString>(this);
     QObject::connect(futureWatcher, &QFutureWatcher<QString>::finished, this, &SessionPrivate::onRequestTaskFinished);
+    QObject::connect(futureWatcher, &QFutureWatcher<QString>::finished, this, [ = ]{
+        McpConfigSyncer::instance()->fetchConfigFromServerAsync();
+    });
     futureWatcher->setFuture(future);
 
     QStringList reply;
@@ -992,7 +1008,7 @@ QString SessionPrivate::chatRequest(LLMServerProxy llmAccount, const QString &ct
         LLMServerProxy tmpLLMAccount = llmAccount;
         LLMServerProxy llmAccountDecrypt = tmpLLMAccount.decryptAccount();
 
-        QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(llmAccountDecrypt);
+        QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(llmAccountDecrypt);
         if (copilot.isNull()) {
             qCWarning(logWrapper) << "Failed to get copilot instance - uuid:" << uuid;
             eventloop.quit();
@@ -1088,7 +1104,7 @@ QString SessionPrivate::genImageRequest(LLMServerProxy tmpLLMAccount, const QStr
 
         // 免费账号需要解密
         LLMServerProxy tmpLLMAccountDecrypt = tmpLLMAccountLocal.decryptAccount();
-        QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(tmpLLMAccountDecrypt);
+        QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(tmpLLMAccountDecrypt);
         copilot->setCreatedId(uuid);
         connect(m_q, &Session::executionAborted, copilot.data(), &LLM::aborted);
 
@@ -1211,7 +1227,7 @@ QString SessionPrivate::searchRequest(LLMServerProxy llmAccount, const QString &
     LLMServerProxy tmpLLMAccount = llmAccount;
     LLMServerProxy llmAccountDecrypt = tmpLLMAccount.decryptAccount();
 
-    QSharedPointer<LLM> copilot = m_llmVendor.getCopilot(llmAccountDecrypt);
+    QSharedPointer<LLM> copilot = LLMVendor()->getCopilot(llmAccountDecrypt);
     if (copilot.isNull()) {
         onError(uuid, AIServer::ContentAccessDenied, "Invalid LLM Account.");
         return uuid;
@@ -1243,12 +1259,72 @@ QString SessionPrivate::searchRequest(LLMServerProxy llmAccount, const QString &
     return uuid;
 }
 
+void SessionPrivate::claimUsageRequest(LLMServerProxy llmAccount)
+{
+    QString uuid = QUuid::createUuid().toString(QUuid::Id128);
+    qCInfo(logWrapper) << "Starting account limit request:" << uuid;
+
+    if (!llmAccount.isValid())
+        qCWarning(logWrapper) << "Invalid LLM account for request:" << uuid;
+
+    QFuture<void> future = QtConcurrent::run(LLMThreadTaskMana::instance()->threadPool(llmAccount.id), [ = ]() {
+        AIServer::ErrorType errorType;
+        if (llmAccount.type != ModelType::FREE_NORMAL && llmAccount.type != ModelType::FREE_KOL) {
+            qCWarning(logWrapper) << "Only free account can claim usage.";
+            return;
+        }
+
+        int result = 0;
+        QString resultMessage = "";
+        int errorCode = UosFreeAccounts::instance().claimAccountUsage(llmAccount.account.apiKey, result, resultMessage);
+        if (errorCode == QNetworkReply::NoError) {
+            bool claimed = false;
+            switch(result) {
+            case 200: // 领取成功
+                claimed = true;
+                resultMessage = tr("Successfully Claimed");
+                break;
+            case 5001: // 账户不存在
+                resultMessage = tr("Account not found");
+                break;
+            case 5002: // 仅支持DeepSeek账号领取额外额度
+                resultMessage = tr("Only support deepseek account");
+                break;
+            case 5003: // 账号额度尚未用完 NOTE:仅老用户，在新手引导时存在此场景，无需告知用户该情况，默认告诉用户领取成功
+                resultMessage = tr("Successfully Claimed");
+                break;
+            case 5004: // 已参与过活动，无法重复领取
+                claimed = true;
+                resultMessage = tr("You have already participated in the event and cannot claim the reward again.");
+                break;
+            case 500:  // 系统错误
+                resultMessage = tr("Server system error");
+                break;
+            default:
+                resultMessage = tr("Failed to Claim. Please Try Again.");
+                break;
+            }
+
+            QMetaObject::invokeMethod(m_q, "sigClaimAccountUsageFinished", Qt::QueuedConnection,
+                                      Q_ARG(bool, claimed),
+                                      Q_ARG(QString, resultMessage)
+                                      );
+        } else {
+            qCWarning(logWrapper) << "Network error checking account status:" << errorCode;
+            QMetaObject::invokeMethod(m_q, "sigClaimAccountUsageFinished", Qt::QueuedConnection,
+                                      Q_ARG(bool, false),
+                                      Q_ARG(QString, tr("Failed to Claim. Please Try Again."))
+                                      );
+        }
+    });
+}
+
 void SessionPrivate::checkUpdateAssistantAccount(const QString &assistantId)
 {
     qCInfo(logWrapper) << "Checking and updating assistant account for ID:" << assistantId;
     
     QList<AssistantProxy> assistantLst = DbWrapper::localDbWrapper().queryAssistantList();
-    assistantLst << m_llmVendor.queryAssistantList();
+    assistantLst << LLMVendor()->queryAssistantList();
 
     const auto it = std::find_if(assistantLst.begin(), assistantLst.end(), [assistantId](const AssistantProxy & assistant) {
         return assistant.id == assistantId;
@@ -1293,7 +1369,7 @@ void SessionPrivate::onError(const QString &uuid, int errCode, const QString &er
 QVariant SessionPrivate::getFAQ()
 {
     qCInfo(logWrapper) << "Getting FAQ for assistant:" << m_assistantProxy.id;
-    return m_llmVendor.getFAQ(m_assistantProxy.id);
+    return LLMVendor()->getFAQ(m_assistantProxy.id);
 }
 
 void SessionPrivate::increaseAccountUsage(const LLMServerProxy &llmAccount, int chatAction) const
@@ -1319,7 +1395,7 @@ QString SessionPrivate::ragPromptBuild(const QString &conversation)
     }
     QElapsedTimer timer;
     timer.start();
-    QString resultData = EmbeddingServer::getInstance().embeddingSearch(ragQuery, 5, m_assistantProxy.type);
+    QString resultData = EmbeddingServer::getInstance().embeddingSearch(ragQuery, 10, m_assistantProxy.type);
     qint64 elapsed = timer.elapsed();
 
     QJsonObject resultObj = QJsonDocument::fromJson(resultData.toUtf8()).object();
